# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 19:21:23 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
misc.update(
    {
        "OpaqueSecIdentityRef": objc.createStructType(
            "Security.OpaqueSecIdentityRef", b"{__SecIdentity=}", []
        ),
        "SecKeychainSettings": objc.createStructType(
            "Security.SecKeychainSettings",
            b"{SecKeychainSettings=IZZI}",
            ["version", "lockOnSleep", "useLockInterval", "lockInterval"],
        ),
        "SecItemImportExportKeyParameters": objc.createStructType(
            "Security.SecItemImportExportKeyParameters",
            b"{_SecItemImportExportKeyParameters=II@@@@@@}",
            [
                "version",
                "flags",
                "passphrase",
                "alertTitle",
                "alertPrompt",
                "accessRef",
                "keyUsage",
                "keyAttributes",
            ],
        ),
        "SecKeychainAttributeList": objc.createStructType(
            "Security.SecKeychainAttributeList",
            b"{SecKeychainAttributeList=I^{SecKeychainAttribute=II^v}}",
            ["count", "attr"],
        ),
        "SecKeychainAttribute": objc.createStructType(
            "Security.SecKeychainAttribute",
            b"{SecKeychainAttribute=II^v}",
            ["tag", "length", "data"],
        ),
        "SecAsn1Template": objc.createStructType(
            "Security.SecAsn1Template",
            b"{SecAsn1Template_struct=II^vI}",
            ["kind", "offset", "sub", "size"],
        ),
        "SecAsn1Oid": objc.createStructType(
            "Security.SecAsn1Oid", b"{cssm_data=Q^C}", ["Length", "Data"]
        ),
        "OpaqueSecCertificateRef": objc.createStructType(
            "Security.OpaqueSecCertificateRef", b"{__SecCertificate=}", []
        ),
        "SecKeychainAttributeInfo": objc.createStructType(
            "Security.SecKeychainAttributeInfo",
            b"{SecKeychainAttributeInfo=I^I^I}",
            ["count", "tag", "format"],
        ),
        "SecAsn1PubKeyInfo": objc.createStructType(
            "Security.SecAsn1PubKeyInfo",
            b"{_SecAsn1PubKeyInfo={_SecAsn1AlgId={cssm_data=Q^C}{cssm_data=Q^C}}{cssm_data=Q^C}}",
            ["algorithm", "subjectPublicKey"],
        ),
        "SecAsn1AlgId": objc.createStructType(
            "Security.SecAsn1AlgId",
            b"{_SecAsn1AlgId={cssm_data=Q^C}{cssm_data=Q^C}}",
            ["algorithm", "parameters"],
        ),
        "SecAsn1Item": objc.createStructType(
            "Security.SecAsn1Item", b"{cssm_data=Q^C}", ["Length", "Data"]
        ),
        "OpaqueSecAccessRef": objc.createStructType(
            "Security.OpaqueSecAccessRef", b"{__SecAccess=}", []
        ),
        "SecKeychainCallbackInfo": objc.createStructType(
            "Security.SecKeychainCallbackInfo",
            b"{SecKeychainCallbackInfo=I^{__SecKeychainItem=}^{__SecKeychain=}i}",
            ["version", "item", "keychain", "pid"],
        ),
        "AuthorizationItem": objc.createStructType(
            "Security.AuthorizationItem",
            b"{_AuthorizationItem=^cL^vI}",
            ["name", "valueLength", "value", "flags"],
        ),
        "AuthorizationExternalForm": objc.createStructType(
            "Security.AuthorizationExternalForm",
            b"{_AuthorizationExternalForm=[32C]}",
            ["bytes"],
        ),
        "OpaqueSecKeyRef": objc.createStructType(
            "Security.OpaqueSecKeyRef", b"{__SecKey=}", []
        ),
    }
)
constants = """$kCMSEncoderDigestAlgorithmSHA1$kCMSEncoderDigestAlgorithmSHA256$kSSLSessionConfig_3DES_fallback$kSSLSessionConfig_ATSv1$kSSLSessionConfig_ATSv1_noPFS$kSSLSessionConfig_RC4_fallback$kSSLSessionConfig_TLSv1_3DES_fallback$kSSLSessionConfig_TLSv1_RC4_fallback$kSSLSessionConfig_TLSv1_fallback$kSSLSessionConfig_anonymous$kSSLSessionConfig_default$kSSLSessionConfig_legacy$kSSLSessionConfig_legacy_DHE$kSSLSessionConfig_standard$kSecACLAuthorizationAny$kSecACLAuthorizationChangeACL$kSecACLAuthorizationChangeOwner$kSecACLAuthorizationDecrypt$kSecACLAuthorizationDelete$kSecACLAuthorizationDerive$kSecACLAuthorizationEncrypt$kSecACLAuthorizationExportClear$kSecACLAuthorizationExportWrapped$kSecACLAuthorizationGenKey$kSecACLAuthorizationImportClear$kSecACLAuthorizationImportWrapped$kSecACLAuthorizationIntegrity$kSecACLAuthorizationKeychainCreate$kSecACLAuthorizationKeychainDelete$kSecACLAuthorizationKeychainItemDelete$kSecACLAuthorizationKeychainItemInsert$kSecACLAuthorizationKeychainItemModify$kSecACLAuthorizationKeychainItemRead$kSecACLAuthorizationLogin$kSecACLAuthorizationMAC$kSecACLAuthorizationPartitionID$kSecACLAuthorizationSign$kSecAttrAccess$kSecAttrAccessControl$kSecAttrAccessGroup$kSecAttrAccessGroupToken$kSecAttrAccessible$kSecAttrAccessibleAfterFirstUnlock$kSecAttrAccessibleAfterFirstUnlockThisDeviceOnly$kSecAttrAccessibleAlways$kSecAttrAccessibleAlwaysThisDeviceOnly$kSecAttrAccessibleWhenPasscodeSetThisDeviceOnly$kSecAttrAccessibleWhenUnlocked$kSecAttrAccessibleWhenUnlockedThisDeviceOnly$kSecAttrAccount$kSecAttrApplicationLabel$kSecAttrApplicationTag$kSecAttrAuthenticationType$kSecAttrAuthenticationTypeDPA$kSecAttrAuthenticationTypeDefault$kSecAttrAuthenticationTypeHTMLForm$kSecAttrAuthenticationTypeHTTPBasic$kSecAttrAuthenticationTypeHTTPDigest$kSecAttrAuthenticationTypeMSN$kSecAttrAuthenticationTypeNTLM$kSecAttrAuthenticationTypeRPA$kSecAttrCanDecrypt$kSecAttrCanDerive$kSecAttrCanEncrypt$kSecAttrCanSign$kSecAttrCanUnwrap$kSecAttrCanVerify$kSecAttrCanWrap$kSecAttrCertificateEncoding$kSecAttrCertificateType$kSecAttrComment$kSecAttrCreationDate$kSecAttrCreator$kSecAttrDescription$kSecAttrEffectiveKeySize$kSecAttrGeneric$kSecAttrIsExtractable$kSecAttrIsInvisible$kSecAttrIsNegative$kSecAttrIsPermanent$kSecAttrIsSensitive$kSecAttrIssuer$kSecAttrKeyClass$kSecAttrKeyClassPrivate$kSecAttrKeyClassPublic$kSecAttrKeyClassSymmetric$kSecAttrKeySizeInBits$kSecAttrKeyType$kSecAttrKeyType3DES$kSecAttrKeyTypeAES$kSecAttrKeyTypeCAST$kSecAttrKeyTypeDES$kSecAttrKeyTypeDSA$kSecAttrKeyTypeEC$kSecAttrKeyTypeECDSA$kSecAttrKeyTypeECSECPrimeRandom$kSecAttrKeyTypeRC2$kSecAttrKeyTypeRC4$kSecAttrKeyTypeRSA$kSecAttrLabel$kSecAttrModificationDate$kSecAttrPRF$kSecAttrPRFHmacAlgSHA1$kSecAttrPRFHmacAlgSHA224$kSecAttrPRFHmacAlgSHA256$kSecAttrPRFHmacAlgSHA384$kSecAttrPRFHmacAlgSHA512$kSecAttrPath$kSecAttrPersistantReference$kSecAttrPersistentReference$kSecAttrPort$kSecAttrProtocol$kSecAttrProtocolAFP$kSecAttrProtocolAppleTalk$kSecAttrProtocolDAAP$kSecAttrProtocolEPPC$kSecAttrProtocolFTP$kSecAttrProtocolFTPAccount$kSecAttrProtocolFTPProxy$kSecAttrProtocolFTPS$kSecAttrProtocolHTTP$kSecAttrProtocolHTTPProxy$kSecAttrProtocolHTTPS$kSecAttrProtocolHTTPSProxy$kSecAttrProtocolIMAP$kSecAttrProtocolIMAPS$kSecAttrProtocolIPP$kSecAttrProtocolIRC$kSecAttrProtocolIRCS$kSecAttrProtocolLDAP$kSecAttrProtocolLDAPS$kSecAttrProtocolNNTP$kSecAttrProtocolNNTPS$kSecAttrProtocolPOP3$kSecAttrProtocolPOP3S$kSecAttrProtocolRTSP$kSecAttrProtocolRTSPProxy$kSecAttrProtocolSMB$kSecAttrProtocolSMTP$kSecAttrProtocolSOCKS$kSecAttrProtocolSSH$kSecAttrProtocolTelnet$kSecAttrProtocolTelnetS$kSecAttrPublicKeyHash$kSecAttrRounds$kSecAttrSalt$kSecAttrSecurityDomain$kSecAttrSerialNumber$kSecAttrServer$kSecAttrService$kSecAttrSubject$kSecAttrSubjectKeyID$kSecAttrSyncViewHint$kSecAttrSynchronizable$kSecAttrSynchronizableAny$kSecAttrTokenID$kSecAttrTokenIDSecureEnclave$kSecAttrType$kSecBase32Encoding$kSecBase64Encoding$kSecCFErrorArchitecture$kSecCFErrorGuestAttributes$kSecCFErrorInfoPlist$kSecCFErrorPath$kSecCFErrorPattern$kSecCFErrorRequirementSyntax$kSecCFErrorResourceAdded$kSecCFErrorResourceAltered$kSecCFErrorResourceMissing$kSecCFErrorResourceSeal$kSecCFErrorResourceSideband$kSecClass$kSecClassCertificate$kSecClassGenericPassword$kSecClassIdentity$kSecClassInternetPassword$kSecClassKey$kSecCodeAttributeArchitecture$kSecCodeAttributeBundleVersion$kSecCodeAttributeSubarchitecture$kSecCodeAttributeUniversalFileOffset$kSecCodeInfoCMS$kSecCodeInfoCdHashes$kSecCodeInfoCertificates$kSecCodeInfoChangedFiles$kSecCodeInfoDesignatedRequirement$kSecCodeInfoDigestAlgorithm$kSecCodeInfoDigestAlgorithms$kSecCodeInfoEntitlements$kSecCodeInfoEntitlementsDict$kSecCodeInfoFlags$kSecCodeInfoFormat$kSecCodeInfoIdentifier$kSecCodeInfoImplicitDesignatedRequirement$kSecCodeInfoMainExecutable$kSecCodeInfoPList$kSecCodeInfoPlatformIdentifier$kSecCodeInfoRequirementData$kSecCodeInfoRequirements$kSecCodeInfoRuntimeVersion$kSecCodeInfoSource$kSecCodeInfoStatus$kSecCodeInfoTeamIdentifier$kSecCodeInfoTime$kSecCodeInfoTimestamp$kSecCodeInfoTrust$kSecCodeInfoUnique$kSecCompressionRatio$kSecDecodeTypeAttribute$kSecDigestHMACKeyAttribute$kSecDigestHMACMD5$kSecDigestHMACSHA1$kSecDigestHMACSHA2$kSecDigestLengthAttribute$kSecDigestMD2$kSecDigestMD4$kSecDigestMD5$kSecDigestSHA1$kSecDigestSHA2$kSecDigestTypeAttribute$kSecEncodeLineLengthAttribute$kSecEncodeTypeAttribute$kSecEncryptKey$kSecEncryptionMode$kSecGuestAttributeArchitecture$kSecGuestAttributeAudit$kSecGuestAttributeCanonical$kSecGuestAttributeDynamicCode$kSecGuestAttributeDynamicCodeInfoPlist$kSecGuestAttributeHash$kSecGuestAttributeMachPort$kSecGuestAttributePid$kSecGuestAttributeSubarchitecture$kSecIVKey$kSecIdentityDomainDefault$kSecIdentityDomainKerberosKDC$kSecImportExportAccess$kSecImportExportKeychain$kSecImportExportPassphrase$kSecImportItemCertChain$kSecImportItemIdentity$kSecImportItemKeyID$kSecImportItemLabel$kSecImportItemTrust$kSecInputIsAttributeName$kSecInputIsDigest$kSecInputIsPlainText$kSecInputIsRaw$kSecKeyAlgorithmECDHKeyExchangeCofactor$kSecKeyAlgorithmECDHKeyExchangeCofactorX963SHA1$kSecKeyAlgorithmECDHKeyExchangeCofactorX963SHA224$kSecKeyAlgorithmECDHKeyExchangeCofactorX963SHA256$kSecKeyAlgorithmECDHKeyExchangeCofactorX963SHA384$kSecKeyAlgorithmECDHKeyExchangeCofactorX963SHA512$kSecKeyAlgorithmECDHKeyExchangeStandard$kSecKeyAlgorithmECDHKeyExchangeStandardX963SHA1$kSecKeyAlgorithmECDHKeyExchangeStandardX963SHA224$kSecKeyAlgorithmECDHKeyExchangeStandardX963SHA256$kSecKeyAlgorithmECDHKeyExchangeStandardX963SHA384$kSecKeyAlgorithmECDHKeyExchangeStandardX963SHA512$kSecKeyAlgorithmECDSASignatureDigestX962$kSecKeyAlgorithmECDSASignatureDigestX962SHA1$kSecKeyAlgorithmECDSASignatureDigestX962SHA224$kSecKeyAlgorithmECDSASignatureDigestX962SHA256$kSecKeyAlgorithmECDSASignatureDigestX962SHA384$kSecKeyAlgorithmECDSASignatureDigestX962SHA512$kSecKeyAlgorithmECDSASignatureMessageX962SHA1$kSecKeyAlgorithmECDSASignatureMessageX962SHA224$kSecKeyAlgorithmECDSASignatureMessageX962SHA256$kSecKeyAlgorithmECDSASignatureMessageX962SHA384$kSecKeyAlgorithmECDSASignatureMessageX962SHA512$kSecKeyAlgorithmECDSASignatureRFC4754$kSecKeyAlgorithmECIESEncryptionCofactorVariableIVX963SHA224AESGCM$kSecKeyAlgorithmECIESEncryptionCofactorVariableIVX963SHA256AESGCM$kSecKeyAlgorithmECIESEncryptionCofactorVariableIVX963SHA384AESGCM$kSecKeyAlgorithmECIESEncryptionCofactorVariableIVX963SHA512AESGCM$kSecKeyAlgorithmECIESEncryptionCofactorX963SHA1AESGCM$kSecKeyAlgorithmECIESEncryptionCofactorX963SHA224AESGCM$kSecKeyAlgorithmECIESEncryptionCofactorX963SHA256AESGCM$kSecKeyAlgorithmECIESEncryptionCofactorX963SHA384AESGCM$kSecKeyAlgorithmECIESEncryptionCofactorX963SHA512AESGCM$kSecKeyAlgorithmECIESEncryptionStandardVariableIVX963SHA224AESGCM$kSecKeyAlgorithmECIESEncryptionStandardVariableIVX963SHA256AESGCM$kSecKeyAlgorithmECIESEncryptionStandardVariableIVX963SHA384AESGCM$kSecKeyAlgorithmECIESEncryptionStandardVariableIVX963SHA512AESGCM$kSecKeyAlgorithmECIESEncryptionStandardX963SHA1AESGCM$kSecKeyAlgorithmECIESEncryptionStandardX963SHA224AESGCM$kSecKeyAlgorithmECIESEncryptionStandardX963SHA256AESGCM$kSecKeyAlgorithmECIESEncryptionStandardX963SHA384AESGCM$kSecKeyAlgorithmECIESEncryptionStandardX963SHA512AESGCM$kSecKeyAlgorithmRSAEncryptionOAEPSHA1$kSecKeyAlgorithmRSAEncryptionOAEPSHA1AESGCM$kSecKeyAlgorithmRSAEncryptionOAEPSHA224$kSecKeyAlgorithmRSAEncryptionOAEPSHA224AESGCM$kSecKeyAlgorithmRSAEncryptionOAEPSHA256$kSecKeyAlgorithmRSAEncryptionOAEPSHA256AESGCM$kSecKeyAlgorithmRSAEncryptionOAEPSHA384$kSecKeyAlgorithmRSAEncryptionOAEPSHA384AESGCM$kSecKeyAlgorithmRSAEncryptionOAEPSHA512$kSecKeyAlgorithmRSAEncryptionOAEPSHA512AESGCM$kSecKeyAlgorithmRSAEncryptionPKCS1$kSecKeyAlgorithmRSAEncryptionRaw$kSecKeyAlgorithmRSASignatureDigestPKCS1v15Raw$kSecKeyAlgorithmRSASignatureDigestPKCS1v15SHA1$kSecKeyAlgorithmRSASignatureDigestPKCS1v15SHA224$kSecKeyAlgorithmRSASignatureDigestPKCS1v15SHA256$kSecKeyAlgorithmRSASignatureDigestPKCS1v15SHA384$kSecKeyAlgorithmRSASignatureDigestPKCS1v15SHA512$kSecKeyAlgorithmRSASignatureDigestPSSSHA1$kSecKeyAlgorithmRSASignatureDigestPSSSHA224$kSecKeyAlgorithmRSASignatureDigestPSSSHA256$kSecKeyAlgorithmRSASignatureDigestPSSSHA384$kSecKeyAlgorithmRSASignatureDigestPSSSHA512$kSecKeyAlgorithmRSASignatureMessagePKCS1v15SHA1$kSecKeyAlgorithmRSASignatureMessagePKCS1v15SHA224$kSecKeyAlgorithmRSASignatureMessagePKCS1v15SHA256$kSecKeyAlgorithmRSASignatureMessagePKCS1v15SHA384$kSecKeyAlgorithmRSASignatureMessagePKCS1v15SHA512$kSecKeyAlgorithmRSASignatureMessagePSSSHA1$kSecKeyAlgorithmRSASignatureMessagePSSSHA224$kSecKeyAlgorithmRSASignatureMessagePSSSHA256$kSecKeyAlgorithmRSASignatureMessagePSSSHA384$kSecKeyAlgorithmRSASignatureMessagePSSSHA512$kSecKeyAlgorithmRSASignatureRaw$kSecKeyAttributeName$kSecKeyKeyExchangeParameterRequestedSize$kSecKeyKeyExchangeParameterSharedInfo$kSecLineLength64$kSecLineLength76$kSecMatchCaseInsensitive$kSecMatchDiacriticInsensitive$kSecMatchEmailAddressIfPresent$kSecMatchIssuers$kSecMatchItemList$kSecMatchLimit$kSecMatchLimitAll$kSecMatchLimitOne$kSecMatchPolicy$kSecMatchSearchList$kSecMatchSubjectContains$kSecMatchSubjectEndsWith$kSecMatchSubjectStartsWith$kSecMatchSubjectWholeString$kSecMatchTrustedOnly$kSecMatchValidOnDate$kSecMatchWidthInsensitive$kSecModeCBCKey$kSecModeCFBKey$kSecModeECBKey$kSecModeNoneKey$kSecModeOFBKey$kSecOAEPEncodingParametersAttributeName$kSecOAEPMGF1DigestAlgorithmAttributeName$kSecOAEPMessageLengthAttributeName$kSecOIDADC_CERT_POLICY$kSecOIDAPPLE_CERT_POLICY$kSecOIDAPPLE_EKU_CODE_SIGNING$kSecOIDAPPLE_EKU_CODE_SIGNING_DEV$kSecOIDAPPLE_EKU_ICHAT_ENCRYPTION$kSecOIDAPPLE_EKU_ICHAT_SIGNING$kSecOIDAPPLE_EKU_RESOURCE_SIGNING$kSecOIDAPPLE_EKU_SYSTEM_IDENTITY$kSecOIDAPPLE_EXTENSION$kSecOIDAPPLE_EXTENSION_AAI_INTERMEDIATE$kSecOIDAPPLE_EXTENSION_ADC_APPLE_SIGNING$kSecOIDAPPLE_EXTENSION_ADC_DEV_SIGNING$kSecOIDAPPLE_EXTENSION_APPLEID_INTERMEDIATE$kSecOIDAPPLE_EXTENSION_APPLE_SIGNING$kSecOIDAPPLE_EXTENSION_CODE_SIGNING$kSecOIDAPPLE_EXTENSION_INTERMEDIATE_MARKER$kSecOIDAPPLE_EXTENSION_ITMS_INTERMEDIATE$kSecOIDAPPLE_EXTENSION_WWDR_INTERMEDIATE$kSecOIDAuthorityInfoAccess$kSecOIDAuthorityKeyIdentifier$kSecOIDBasicConstraints$kSecOIDBiometricInfo$kSecOIDCSSMKeyStruct$kSecOIDCertIssuer$kSecOIDCertificatePolicies$kSecOIDClientAuth$kSecOIDCollectiveStateProvinceName$kSecOIDCollectiveStreetAddress$kSecOIDCommonName$kSecOIDCountryName$kSecOIDCrlDistributionPoints$kSecOIDCrlNumber$kSecOIDCrlReason$kSecOIDDOTMAC_CERT_EMAIL_ENCRYPT$kSecOIDDOTMAC_CERT_EMAIL_SIGN$kSecOIDDOTMAC_CERT_EXTENSION$kSecOIDDOTMAC_CERT_IDENTITY$kSecOIDDOTMAC_CERT_POLICY$kSecOIDDeltaCrlIndicator$kSecOIDDescription$kSecOIDEKU_IPSec$kSecOIDEmailAddress$kSecOIDEmailProtection$kSecOIDExtendedKeyUsage$kSecOIDExtendedKeyUsageAny$kSecOIDExtendedUseCodeSigning$kSecOIDGivenName$kSecOIDHoldInstructionCode$kSecOIDInvalidityDate$kSecOIDIssuerAltName$kSecOIDIssuingDistributionPoint$kSecOIDIssuingDistributionPoints$kSecOIDKERBv5_PKINIT_KP_CLIENT_AUTH$kSecOIDKERBv5_PKINIT_KP_KDC$kSecOIDKeyUsage$kSecOIDLocalityName$kSecOIDMS_NTPrincipalName$kSecOIDMicrosoftSGC$kSecOIDNameConstraints$kSecOIDNetscapeCertSequence$kSecOIDNetscapeCertType$kSecOIDNetscapeSGC$kSecOIDOCSPSigning$kSecOIDOrganizationName$kSecOIDOrganizationalUnitName$kSecOIDPolicyConstraints$kSecOIDPolicyMappings$kSecOIDPrivateKeyUsagePeriod$kSecOIDQC_Statements$kSecOIDSRVName$kSecOIDSerialNumber$kSecOIDServerAuth$kSecOIDStateProvinceName$kSecOIDStreetAddress$kSecOIDSubjectAltName$kSecOIDSubjectDirectoryAttributes$kSecOIDSubjectEmailAddress$kSecOIDSubjectInfoAccess$kSecOIDSubjectKeyIdentifier$kSecOIDSubjectPicture$kSecOIDSubjectSignatureBitmap$kSecOIDSurname$kSecOIDTimeStamping$kSecOIDTitle$kSecOIDUseExemptions$kSecOIDX509V1CertificateIssuerUniqueId$kSecOIDX509V1CertificateSubjectUniqueId$kSecOIDX509V1IssuerName$kSecOIDX509V1IssuerNameCStruct$kSecOIDX509V1IssuerNameLDAP$kSecOIDX509V1IssuerNameStd$kSecOIDX509V1SerialNumber$kSecOIDX509V1Signature$kSecOIDX509V1SignatureAlgorithm$kSecOIDX509V1SignatureAlgorithmParameters$kSecOIDX509V1SignatureAlgorithmTBS$kSecOIDX509V1SignatureCStruct$kSecOIDX509V1SignatureStruct$kSecOIDX509V1SubjectName$kSecOIDX509V1SubjectNameCStruct$kSecOIDX509V1SubjectNameLDAP$kSecOIDX509V1SubjectNameStd$kSecOIDX509V1SubjectPublicKey$kSecOIDX509V1SubjectPublicKeyAlgorithm$kSecOIDX509V1SubjectPublicKeyAlgorithmParameters$kSecOIDX509V1SubjectPublicKeyCStruct$kSecOIDX509V1ValidityNotAfter$kSecOIDX509V1ValidityNotBefore$kSecOIDX509V1Version$kSecOIDX509V3Certificate$kSecOIDX509V3CertificateCStruct$kSecOIDX509V3CertificateExtensionCStruct$kSecOIDX509V3CertificateExtensionCritical$kSecOIDX509V3CertificateExtensionId$kSecOIDX509V3CertificateExtensionStruct$kSecOIDX509V3CertificateExtensionType$kSecOIDX509V3CertificateExtensionValue$kSecOIDX509V3CertificateExtensionsCStruct$kSecOIDX509V3CertificateExtensionsStruct$kSecOIDX509V3CertificateNumberOfExtensions$kSecOIDX509V3SignedCertificate$kSecOIDX509V3SignedCertificateCStruct$kSecPaddingKey$kSecPaddingNoneKey$kSecPaddingOAEPKey$kSecPaddingPKCS1Key$kSecPaddingPKCS5Key$kSecPaddingPKCS7Key$kSecPolicyAppleCodeSigning$kSecPolicyAppleEAP$kSecPolicyAppleIDValidation$kSecPolicyAppleIPsec$kSecPolicyApplePKINITClient$kSecPolicyApplePKINITServer$kSecPolicyApplePassbookSigning$kSecPolicyApplePayIssuerEncryption$kSecPolicyAppleRevocation$kSecPolicyAppleSMIME$kSecPolicyAppleSSL$kSecPolicyAppleTimeStamping$kSecPolicyAppleX509Basic$kSecPolicyAppleiChat$kSecPolicyClient$kSecPolicyKU_CRLSign$kSecPolicyKU_DataEncipherment$kSecPolicyKU_DecipherOnly$kSecPolicyKU_DigitalSignature$kSecPolicyKU_EncipherOnly$kSecPolicyKU_KeyAgreement$kSecPolicyKU_KeyCertSign$kSecPolicyKU_KeyEncipherment$kSecPolicyKU_NonRepudiation$kSecPolicyMacAppStoreReceipt$kSecPolicyName$kSecPolicyOid$kSecPolicyRevocationFlags$kSecPolicyTeamIdentifier$kSecPrivateKeyAttrs$kSecPropertyKeyLabel$kSecPropertyKeyLocalizedLabel$kSecPropertyKeyType$kSecPropertyKeyValue$kSecPropertyTypeArray$kSecPropertyTypeData$kSecPropertyTypeDate$kSecPropertyTypeError$kSecPropertyTypeNumber$kSecPropertyTypeSection$kSecPropertyTypeString$kSecPropertyTypeSuccess$kSecPropertyTypeTitle$kSecPropertyTypeURL$kSecPropertyTypeWarning$kSecPublicKeyAttrs$kSecRandomDefault@^{__SecRandom=}$kSecReturnAttributes$kSecReturnData$kSecReturnPersistentRef$kSecReturnRef$kSecSharedPassword$kSecSignatureAttributeName$kSecTransformAbortAttributeName$kSecTransformAbortOriginatorKey$kSecTransformActionAttributeNotification$kSecTransformActionAttributeValidation$kSecTransformActionCanExecute$kSecTransformActionExternalizeExtraData$kSecTransformActionFinalize$kSecTransformActionInternalizeExtraData$kSecTransformActionProcessData$kSecTransformActionStartingExecution$kSecTransformDebugAttributeName$kSecTransformErrorDomain$kSecTransformInputAttributeName$kSecTransformOutputAttributeName$kSecTransformPreviousErrorKey$kSecTransformTransformName$kSecTrustCertificateTransparency$kSecTrustCertificateTransparencyWhiteList$kSecTrustEvaluationDate$kSecTrustExtendedValidation$kSecTrustOrganizationName$kSecTrustResultValue$kSecTrustRevocationChecked$kSecTrustRevocationValidUntilDate$kSecUseAuthenticationContext$kSecUseAuthenticationUI$kSecUseAuthenticationUIAllow$kSecUseAuthenticationUIFail$kSecUseAuthenticationUISkip$kSecUseDataProtectionKeychain$kSecUseItemList$kSecUseKeychain$kSecUseNoAuthenticationUI$kSecUseOperationPrompt$kSecValueData$kSecValuePersistentRef$kSecValueRef$kSecZLibEncoding$"""
enums = """$SECURITY_TYPE_UNIFICATION@1$SEC_ASN1_ANY@1024$SEC_ASN1_APPLICATION@64$SEC_ASN1_BIT_STRING@3$SEC_ASN1_BMP_STRING@30$SEC_ASN1_BOOLEAN@1$SEC_ASN1_CHOICE@1048576$SEC_ASN1_CLASS_MASK@192$SEC_ASN1_CONSTRUCTED@32$SEC_ASN1_CONTEXT_SPECIFIC@128$SEC_ASN1_DYNAMIC@16384$SEC_ASN1_EMBEDDED_PDV@11$SEC_ASN1_ENUMERATED@10$SEC_ASN1_EXPLICIT@512$SEC_ASN1_GENERALIZED_TIME@24$SEC_ASN1_GENERAL_STRING@27$SEC_ASN1_GRAPHIC_STRING@25$SEC_ASN1_GROUP@8192$SEC_ASN1_HIGH_TAG_NUMBER@31$SEC_ASN1_IA5_STRING@22$SEC_ASN1_INLINE@2048$SEC_ASN1_INNER@65536$SEC_ASN1_INTEGER@2$SEC_ASN1_METHOD_MASK@32$SEC_ASN1_NULL@5$SEC_ASN1_NUMERIC_STRING@18$SEC_ASN1_OBJECT_DESCRIPTOR@7$SEC_ASN1_OBJECT_ID@6$SEC_ASN1_OCTET_STRING@4$SEC_ASN1_OPTIONAL@256$SEC_ASN1_POINTER@4096$SEC_ASN1_PRIMITIVE@0$SEC_ASN1_PRINTABLE_STRING@19$SEC_ASN1_PRIVATE@192$SEC_ASN1_REAL@9$SEC_ASN1_SAVE@131072$SEC_ASN1_SEQUENCE@16$SEC_ASN1_SET@17$SEC_ASN1_SIGNED_INT@8388608$SEC_ASN1_SKIP@32768$SEC_ASN1_SKIP_REST@524288$SEC_ASN1_T61_STRING@20$SEC_ASN1_TAGNUM_MASK@31$SEC_ASN1_TAG_MASK@255$SEC_ASN1_UNIVERSAL@0$SEC_ASN1_UNIVERSAL_STRING@28$SEC_ASN1_UTC_TIME@23$SEC_ASN1_UTF8_STRING@12$SEC_ASN1_VIDEOTEX_STRING@21$SEC_ASN1_VISIBLE_STRING@26$SEC_KEYCHAIN_SETTINGS_VERS1@1$SEC_KEY_IMPORT_EXPORT_PARAMS_VERSION@0$SEC_PROTOCOL_CERT_COMPRESSION_DEFAULT@1$SSL_DHE_DSS_EXPORT_WITH_DES40_CBC_SHA@17$SSL_DHE_DSS_WITH_3DES_EDE_CBC_SHA@19$SSL_DHE_DSS_WITH_DES_CBC_SHA@18$SSL_DHE_RSA_EXPORT_WITH_DES40_CBC_SHA@20$SSL_DHE_RSA_WITH_3DES_EDE_CBC_SHA@22$SSL_DHE_RSA_WITH_DES_CBC_SHA@21$SSL_DH_DSS_EXPORT_WITH_DES40_CBC_SHA@11$SSL_DH_DSS_WITH_3DES_EDE_CBC_SHA@13$SSL_DH_DSS_WITH_DES_CBC_SHA@12$SSL_DH_RSA_EXPORT_WITH_DES40_CBC_SHA@14$SSL_DH_RSA_WITH_3DES_EDE_CBC_SHA@16$SSL_DH_RSA_WITH_DES_CBC_SHA@15$SSL_DH_anon_EXPORT_WITH_DES40_CBC_SHA@25$SSL_DH_anon_EXPORT_WITH_RC4_40_MD5@23$SSL_DH_anon_WITH_3DES_EDE_CBC_SHA@27$SSL_DH_anon_WITH_DES_CBC_SHA@26$SSL_DH_anon_WITH_RC4_128_MD5@24$SSL_FORTEZZA_DMS_WITH_FORTEZZA_CBC_SHA@29$SSL_FORTEZZA_DMS_WITH_NULL_SHA@28$SSL_NO_SUCH_CIPHERSUITE@65535$SSL_NULL_WITH_NULL_NULL@0$SSL_RSA_EXPORT_WITH_DES40_CBC_SHA@8$SSL_RSA_EXPORT_WITH_RC2_CBC_40_MD5@6$SSL_RSA_EXPORT_WITH_RC4_40_MD5@3$SSL_RSA_WITH_3DES_EDE_CBC_MD5@65411$SSL_RSA_WITH_3DES_EDE_CBC_SHA@10$SSL_RSA_WITH_DES_CBC_MD5@65410$SSL_RSA_WITH_DES_CBC_SHA@9$SSL_RSA_WITH_IDEA_CBC_MD5@65409$SSL_RSA_WITH_IDEA_CBC_SHA@7$SSL_RSA_WITH_NULL_MD5@1$SSL_RSA_WITH_NULL_SHA@2$SSL_RSA_WITH_RC2_CBC_MD5@65408$SSL_RSA_WITH_RC4_128_MD5@4$SSL_RSA_WITH_RC4_128_SHA@5$TLS_AES_128_CCM_8_SHA256@4869$TLS_AES_128_CCM_SHA256@4868$TLS_AES_128_GCM_SHA256@4865$TLS_AES_256_GCM_SHA384@4866$TLS_CHACHA20_POLY1305_SHA256@4867$TLS_DHE_DSS_WITH_3DES_EDE_CBC_SHA@19$TLS_DHE_DSS_WITH_AES_128_CBC_SHA@50$TLS_DHE_DSS_WITH_AES_128_CBC_SHA256@64$TLS_DHE_DSS_WITH_AES_128_GCM_SHA256@162$TLS_DHE_DSS_WITH_AES_256_CBC_SHA@56$TLS_DHE_DSS_WITH_AES_256_CBC_SHA256@106$TLS_DHE_DSS_WITH_AES_256_GCM_SHA384@163$TLS_DHE_PSK_WITH_3DES_EDE_CBC_SHA@143$TLS_DHE_PSK_WITH_AES_128_CBC_SHA@144$TLS_DHE_PSK_WITH_AES_128_CBC_SHA256@178$TLS_DHE_PSK_WITH_AES_128_GCM_SHA256@170$TLS_DHE_PSK_WITH_AES_256_CBC_SHA@145$TLS_DHE_PSK_WITH_AES_256_CBC_SHA384@179$TLS_DHE_PSK_WITH_AES_256_GCM_SHA384@171$TLS_DHE_PSK_WITH_NULL_SHA@45$TLS_DHE_PSK_WITH_NULL_SHA256@180$TLS_DHE_PSK_WITH_NULL_SHA384@181$TLS_DHE_PSK_WITH_RC4_128_SHA@142$TLS_DHE_RSA_WITH_3DES_EDE_CBC_SHA@22$TLS_DHE_RSA_WITH_AES_128_CBC_SHA@51$TLS_DHE_RSA_WITH_AES_128_CBC_SHA256@103$TLS_DHE_RSA_WITH_AES_128_GCM_SHA256@158$TLS_DHE_RSA_WITH_AES_256_CBC_SHA@57$TLS_DHE_RSA_WITH_AES_256_CBC_SHA256@107$TLS_DHE_RSA_WITH_AES_256_GCM_SHA384@159$TLS_DH_DSS_WITH_3DES_EDE_CBC_SHA@13$TLS_DH_DSS_WITH_AES_128_CBC_SHA@48$TLS_DH_DSS_WITH_AES_128_CBC_SHA256@62$TLS_DH_DSS_WITH_AES_128_GCM_SHA256@164$TLS_DH_DSS_WITH_AES_256_CBC_SHA@54$TLS_DH_DSS_WITH_AES_256_CBC_SHA256@104$TLS_DH_DSS_WITH_AES_256_GCM_SHA384@165$TLS_DH_RSA_WITH_3DES_EDE_CBC_SHA@16$TLS_DH_RSA_WITH_AES_128_CBC_SHA@49$TLS_DH_RSA_WITH_AES_128_CBC_SHA256@63$TLS_DH_RSA_WITH_AES_128_GCM_SHA256@160$TLS_DH_RSA_WITH_AES_256_CBC_SHA@55$TLS_DH_RSA_WITH_AES_256_CBC_SHA256@105$TLS_DH_RSA_WITH_AES_256_GCM_SHA384@161$TLS_DH_anon_WITH_3DES_EDE_CBC_SHA@27$TLS_DH_anon_WITH_AES_128_CBC_SHA@52$TLS_DH_anon_WITH_AES_128_CBC_SHA256@108$TLS_DH_anon_WITH_AES_128_GCM_SHA256@166$TLS_DH_anon_WITH_AES_256_CBC_SHA@58$TLS_DH_anon_WITH_AES_256_CBC_SHA256@109$TLS_DH_anon_WITH_AES_256_GCM_SHA384@167$TLS_DH_anon_WITH_RC4_128_MD5@24$TLS_ECDHE_ECDSA_WITH_3DES_EDE_CBC_SHA@49160$TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA@49161$TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256@49187$TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256@49195$TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA@49162$TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384@49188$TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384@49196$TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256@52393$TLS_ECDHE_ECDSA_WITH_NULL_SHA@49158$TLS_ECDHE_ECDSA_WITH_RC4_128_SHA@49159$TLS_ECDHE_PSK_WITH_AES_128_CBC_SHA@49205$TLS_ECDHE_PSK_WITH_AES_256_CBC_SHA@49206$TLS_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA@49170$TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA@49171$TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256@49191$TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256@49199$TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA@49172$TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384@49192$TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384@49200$TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256@52392$TLS_ECDHE_RSA_WITH_NULL_SHA@49168$TLS_ECDHE_RSA_WITH_RC4_128_SHA@49169$TLS_ECDH_ECDSA_WITH_3DES_EDE_CBC_SHA@49155$TLS_ECDH_ECDSA_WITH_AES_128_CBC_SHA@49156$TLS_ECDH_ECDSA_WITH_AES_128_CBC_SHA256@49189$TLS_ECDH_ECDSA_WITH_AES_128_GCM_SHA256@49197$TLS_ECDH_ECDSA_WITH_AES_256_CBC_SHA@49157$TLS_ECDH_ECDSA_WITH_AES_256_CBC_SHA384@49190$TLS_ECDH_ECDSA_WITH_AES_256_GCM_SHA384@49198$TLS_ECDH_ECDSA_WITH_NULL_SHA@49153$TLS_ECDH_ECDSA_WITH_RC4_128_SHA@49154$TLS_ECDH_RSA_WITH_3DES_EDE_CBC_SHA@49165$TLS_ECDH_RSA_WITH_AES_128_CBC_SHA@49166$TLS_ECDH_RSA_WITH_AES_128_CBC_SHA256@49193$TLS_ECDH_RSA_WITH_AES_128_GCM_SHA256@49201$TLS_ECDH_RSA_WITH_AES_256_CBC_SHA@49167$TLS_ECDH_RSA_WITH_AES_256_CBC_SHA384@49194$TLS_ECDH_RSA_WITH_AES_256_GCM_SHA384@49202$TLS_ECDH_RSA_WITH_NULL_SHA@49163$TLS_ECDH_RSA_WITH_RC4_128_SHA@49164$TLS_ECDH_anon_WITH_3DES_EDE_CBC_SHA@49175$TLS_ECDH_anon_WITH_AES_128_CBC_SHA@49176$TLS_ECDH_anon_WITH_AES_256_CBC_SHA@49177$TLS_ECDH_anon_WITH_NULL_SHA@49173$TLS_ECDH_anon_WITH_RC4_128_SHA@49174$TLS_EMPTY_RENEGOTIATION_INFO_SCSV@255$TLS_NULL_WITH_NULL_NULL@0$TLS_PSK_WITH_3DES_EDE_CBC_SHA@139$TLS_PSK_WITH_AES_128_CBC_SHA@140$TLS_PSK_WITH_AES_128_CBC_SHA256@174$TLS_PSK_WITH_AES_128_GCM_SHA256@168$TLS_PSK_WITH_AES_256_CBC_SHA@141$TLS_PSK_WITH_AES_256_CBC_SHA384@175$TLS_PSK_WITH_AES_256_GCM_SHA384@169$TLS_PSK_WITH_CHACHA20_POLY1305_SHA256@52395$TLS_PSK_WITH_NULL_SHA@44$TLS_PSK_WITH_NULL_SHA256@176$TLS_PSK_WITH_NULL_SHA384@177$TLS_PSK_WITH_RC4_128_SHA@138$TLS_RSA_PSK_WITH_3DES_EDE_CBC_SHA@147$TLS_RSA_PSK_WITH_AES_128_CBC_SHA@148$TLS_RSA_PSK_WITH_AES_128_CBC_SHA256@182$TLS_RSA_PSK_WITH_AES_128_GCM_SHA256@172$TLS_RSA_PSK_WITH_AES_256_CBC_SHA@149$TLS_RSA_PSK_WITH_AES_256_CBC_SHA384@183$TLS_RSA_PSK_WITH_AES_256_GCM_SHA384@173$TLS_RSA_PSK_WITH_NULL_SHA@46$TLS_RSA_PSK_WITH_NULL_SHA256@184$TLS_RSA_PSK_WITH_NULL_SHA384@185$TLS_RSA_PSK_WITH_RC4_128_SHA@146$TLS_RSA_WITH_3DES_EDE_CBC_SHA@10$TLS_RSA_WITH_AES_128_CBC_SHA@47$TLS_RSA_WITH_AES_128_CBC_SHA256@60$TLS_RSA_WITH_AES_128_GCM_SHA256@156$TLS_RSA_WITH_AES_256_CBC_SHA@53$TLS_RSA_WITH_AES_256_CBC_SHA256@61$TLS_RSA_WITH_AES_256_GCM_SHA384@157$TLS_RSA_WITH_NULL_MD5@1$TLS_RSA_WITH_NULL_SHA@2$TLS_RSA_WITH_NULL_SHA256@59$TLS_RSA_WITH_RC4_128_MD5@4$TLS_RSA_WITH_RC4_128_SHA@5$callerSecuritySession@-1$errAuthorizationBadAddress@-60033$errAuthorizationCanceled@-60006$errAuthorizationDenied@-60005$errAuthorizationExternalizeNotAllowed@-60009$errAuthorizationInteractionNotAllowed@-60007$errAuthorizationInternal@-60008$errAuthorizationInternalizeNotAllowed@-60010$errAuthorizationInvalidFlags@-60011$errAuthorizationInvalidPointer@-60004$errAuthorizationInvalidRef@-60002$errAuthorizationInvalidSet@-60001$errAuthorizationInvalidTag@-60003$errAuthorizationSuccess@0$errAuthorizationToolEnvironmentError@-60032$errAuthorizationToolExecuteFailure@-60031$errSSLATSCertificateHashAlgorithmViolation@-9885$errSSLATSCertificateTrustViolation@-9886$errSSLATSCiphersuiteViolation@-9882$errSSLATSLeafCertificateHashAlgorithmViolation@-9884$errSSLATSMinimumKeySizeViolation@-9883$errSSLATSMinimumVersionViolation@-9881$errSSLATSViolation@-9880$errSSLBadCert@-9808$errSSLBadCertificateStatusResponse@-9862$errSSLBadCipherSuite@-9818$errSSLBadConfiguration@-9848$errSSLBadRecordMac@-9846$errSSLBufferOverflow@-9817$errSSLCertExpired@-9814$errSSLCertNotYetValid@-9815$errSSLCertificateRequired@-9863$errSSLClientCertRequested@-9842$errSSLClientHelloReceived@-9851$errSSLClosedAbort@-9806$errSSLClosedGraceful@-9805$errSSLClosedNoNotify@-9816$errSSLConfigurationFailed@-9854$errSSLConnectionRefused@-9844$errSSLCrypto@-9809$errSSLDecodeError@-9859$errSSLDecompressFail@-9857$errSSLDecryptionFail@-9845$errSSLEarlyDataRejected@-9890$errSSLFatalAlert@-9802$errSSLHandshakeFail@-9858$errSSLHostNameMismatch@-9843$errSSLIllegalParam@-9830$errSSLInappropriateFallback@-9860$errSSLInternal@-9810$errSSLMissingExtension@-9861$errSSLModuleAttach@-9811$errSSLNegotiation@-9801$errSSLNetworkTimeout@-9853$errSSLNoRootCert@-9813$errSSLPeerAccessDenied@-9832$errSSLPeerAuthCompleted@-9841$errSSLPeerBadCert@-9825$errSSLPeerBadRecordMac@-9820$errSSLPeerCertExpired@-9828$errSSLPeerCertRevoked@-9827$errSSLPeerCertUnknown@-9829$errSSLPeerDecodeError@-9833$errSSLPeerDecompressFail@-9823$errSSLPeerDecryptError@-9834$errSSLPeerDecryptionFail@-9821$errSSLPeerExportRestriction@-9835$errSSLPeerHandshakeFail@-9824$errSSLPeerInsufficientSecurity@-9837$errSSLPeerInternalError@-9838$errSSLPeerNoRenegotiation@-9840$errSSLPeerProtocolVersion@-9836$errSSLPeerRecordOverflow@-9822$errSSLPeerUnexpectedMsg@-9819$errSSLPeerUnknownCA@-9831$errSSLPeerUnsupportedCert@-9826$errSSLPeerUserCancelled@-9839$errSSLProtocol@-9800$errSSLRecordOverflow@-9847$errSSLSessionNotFound@-9804$errSSLTransportReset@-9852$errSSLUnexpectedMessage@-9856$errSSLUnexpectedRecord@-9849$errSSLUnknownPSKIdentity@-9864$errSSLUnknownRootCert@-9812$errSSLUnrecognizedName@-9865$errSSLUnsupportedExtension@-9855$errSSLWeakPeerEphemeralDHKey@-9850$errSSLWouldBlock@-9803$errSSLXCertChainInvalid@-9807$errSecACLAddFailed@-67698$errSecACLChangeFailed@-67699$errSecACLDeleteFailed@-67696$errSecACLNotSimple@-25240$errSecACLReplaceFailed@-67697$errSecAddinLoadFailed@-67711$errSecAddinUnloadFailed@-67714$errSecAlgorithmMismatch@-67730$errSecAllocate@-108$errSecAlreadyLoggedIn@-67814$errSecAppleAddAppACLSubject@-67589$errSecAppleInvalidKeyEndDate@-67593$errSecAppleInvalidKeyStartDate@-67592$errSecApplePublicKeyIncomplete@-67590$errSecAppleSSLv2Rollback@-67595$errSecAppleSignatureMismatch@-67591$errSecAttachHandleBusy@-67728$errSecAttributeNotInContext@-67720$errSecAuthFailed@-25293$errSecBadReq@-909$errSecBlockSizeMismatch@-67810$errSecBufferTooSmall@-25301$errSecCRLAlreadySigned@-67684$errSecCRLBadURI@-67617$errSecCRLExpired@-67613$errSecCRLNotFound@-67615$errSecCRLNotTrusted@-67620$errSecCRLNotValidYet@-67614$errSecCRLPolicyFailed@-67621$errSecCRLServerDown@-67616$errSecCSAmbiguousBundleFormat@-67011$errSecCSBadBundleFormat@-67028$errSecCSBadCallbackValue@-67020$errSecCSBadDictionaryFormat@-67058$errSecCSBadDiskImageFormat@-67001$errSecCSBadFrameworkVersion@-67009$errSecCSBadLVArch@-67017$errSecCSBadMainExecutable@-67010$errSecCSBadNestedCode@-67021$errSecCSBadObjectFormat@-67049$errSecCSBadResource@-67054$errSecCSBadTeamIdentifier@-66997$errSecCSCMSTooLarge@-67036$errSecCSCancelled@-67006$errSecCSDBAccess@-67032$errSecCSDBDenied@-67033$errSecCSDSStoreSymlink@-67012$errSecCSDbCorrupt@-67024$errSecCSFileHardQuarantined@-67026$errSecCSGuestInvalid@-67063$errSecCSHelperFailed@-67019$errSecCSHostProtocolContradiction@-67043$errSecCSHostProtocolDedicationError@-67042$errSecCSHostProtocolInvalidAttribute@-67031$errSecCSHostProtocolInvalidHash@-67035$errSecCSHostProtocolNotProxy@-67041$errSecCSHostProtocolRelativePath@-67044$errSecCSHostProtocolStateError@-67040$errSecCSHostProtocolUnrelated@-67039$errSecCSHostReject@-67047$errSecCSInfoPlistFailed@-67030$errSecCSInternalError@-67048$errSecCSInvalidAssociatedFileData@-66999$errSecCSInvalidAttributeValues@-67066$errSecCSInvalidEntitlements@-66994$errSecCSInvalidFlags@-67070$errSecCSInvalidObjectRef@-67071$errSecCSInvalidPlatform@-67005$errSecCSInvalidRuntimeVersion@-66993$errSecCSInvalidSymlink@-67003$errSecCSInvalidTeamIdentifier@-66998$errSecCSMultipleGuests@-67064$errSecCSNoMainExecutable@-67029$errSecCSNoMatches@-67027$errSecCSNoSuchCode@-67065$errSecCSNotAHost@-67046$errSecCSNotAppLike@-67002$errSecCSNotSupported@-67037$errSecCSObjectRequired@-67069$errSecCSOutdated@-67025$errSecCSRegularFile@-67015$errSecCSReqFailed@-67050$errSecCSReqInvalid@-67052$errSecCSReqUnsupported@-67051$errSecCSResourceDirectoryFailed@-67023$errSecCSResourceNotSupported@-67016$errSecCSResourceRulesInvalid@-67053$errSecCSResourcesInvalid@-67055$errSecCSResourcesNotFound@-67056$errSecCSResourcesNotSealed@-67057$errSecCSRevokedNotarization@-66992$errSecCSSigDBAccess@-67032$errSecCSSigDBDenied@-67033$errSecCSSignatureFailed@-67061$errSecCSSignatureInvalid@-67045$errSecCSSignatureNotVerifiable@-67060$errSecCSSignatureUnsupported@-67059$errSecCSSignatureUntrusted@-66996$errSecCSStaticCodeChanged@-67034$errSecCSStaticCodeNotFound@-67068$errSecCSTooBig@-67004$errSecCSUnimplemented@-67072$errSecCSUnsealedAppRoot@-67014$errSecCSUnsealedFrameworkRoot@-67008$errSecCSUnsigned@-67062$errSecCSUnsignedNestedCode@-67022$errSecCSUnsupportedDigestAlgorithm@-67000$errSecCSUnsupportedGuestAttributes@-67067$errSecCSVetoed@-67018$errSecCSWeakResourceEnvelope@-67007$errSecCSWeakResourceRules@-67013$errSecCallbackFailed@-67695$errSecCertificateCannotOperate@-67817$errSecCertificateDuplicateExtension@-67903$errSecCertificateExpired@-67818$errSecCertificateIsCA@-67902$errSecCertificateNameNotAllowed@-67900$errSecCertificateNotValidYet@-67819$errSecCertificatePolicyNotAllowed@-67899$errSecCertificateRevoked@-67820$errSecCertificateSuspended@-67821$errSecCertificateValidityPeriodTooLong@-67901$errSecCodeSigningBadCertChainLength@-67647$errSecCodeSigningBadPathLengthConstraint@-67649$errSecCodeSigningDevelopment@-67651$errSecCodeSigningNoBasicConstraints@-67648$errSecCodeSigningNoExtendedKeyUsage@-67650$errSecConversionError@-67594$errSecCoreFoundationUnknown@-4960$errSecCreateChainFailed@-25318$errSecDataNotAvailable@-25316$errSecDataNotModifiable@-25317$errSecDataTooLarge@-25302$errSecDatabaseLocked@-67869$errSecDatastoreIsOpen@-67870$errSecDecode@-26275$errSecDeviceError@-67727$errSecDeviceFailed@-67588$errSecDeviceReset@-67587$errSecDeviceVerifyFailed@-67812$errSecDiskFull@-34$errSecDskFull@-34$errSecDuplicateCallback@-25297$errSecDuplicateItem@-25299$errSecDuplicateKeychain@-25296$errSecEMMLoadFailed@-67709$errSecEMMUnloadFailed@-67710$errSecEndOfData@-67634$errSecEventNotificationCallbackNotFound@-67723$errSecExtendedKeyUsageNotCritical@-67881$errSecFieldSpecifiedMultiple@-67866$errSecFileTooBig@-67597$errSecFunctionFailed@-67677$errSecFunctionIntegrityFail@-67670$errSecHostNameMismatch@-67602$errSecIDPFailure@-67622$errSecIO@-36$errSecInDarkWake@-25320$errSecIncompatibleDatabaseBlob@-67600$errSecIncompatibleFieldFormat@-67867$errSecIncompatibleKeyBlob@-67601$errSecIncompatibleVersion@-67704$errSecIncompleteCertRevocationCheck@-67635$errSecInputLengthError@-67724$errSecInsufficientClientID@-67586$errSecInsufficientCredentials@-67822$errSecInteractionNotAllowed@-25308$errSecInteractionRequired@-25315$errSecInternalComponent@-2070$errSecInternalError@-67671$errSecInvaldCRLAuthority@-67827$errSecInvalidACL@-67702$errSecInvalidAccessCredentials@-67700$errSecInvalidAccessRequest@-67876$errSecInvalidAction@-67823$errSecInvalidAddinFunctionTable@-67716$errSecInvalidAlgorithm@-67747$errSecInvalidAlgorithmParms@-67770$errSecInvalidAttributeAccessCredentials@-67796$errSecInvalidAttributeBase@-67788$errSecInvalidAttributeBlockSize@-67764$errSecInvalidAttributeDLDBHandle@-67794$errSecInvalidAttributeEffectiveBits@-67778$errSecInvalidAttributeEndDate@-67782$errSecInvalidAttributeInitVector@-67750$errSecInvalidAttributeIterationCount@-67792$errSecInvalidAttributeKey@-67748$errSecInvalidAttributeKeyLength@-67762$errSecInvalidAttributeKeyType@-67774$errSecInvalidAttributeLabel@-67772$errSecInvalidAttributeMode@-67776$errSecInvalidAttributeOutputSize@-67766$errSecInvalidAttributePadding@-67754$errSecInvalidAttributePassphrase@-67760$errSecInvalidAttributePrime@-67786$errSecInvalidAttributePrivateKeyFormat@-67800$errSecInvalidAttributePublicKeyFormat@-67798$errSecInvalidAttributeRandom@-67756$errSecInvalidAttributeRounds@-67768$errSecInvalidAttributeSalt@-67752$errSecInvalidAttributeSeed@-67758$errSecInvalidAttributeStartDate@-67780$errSecInvalidAttributeSubprime@-67790$errSecInvalidAttributeSymmetricKeyFormat@-67802$errSecInvalidAttributeVersion@-67784$errSecInvalidAttributeWrappedKeyFormat@-67804$errSecInvalidAuthority@-67824$errSecInvalidAuthorityKeyID@-67606$errSecInvalidBaseACLs@-67851$errSecInvalidBundleInfo@-67857$errSecInvalidCRL@-67830$errSecInvalidCRLAuthority@-67827$errSecInvalidCRLEncoding@-67828$errSecInvalidCRLGroup@-67816$errSecInvalidCRLIndex@-67858$errSecInvalidCRLType@-67829$errSecInvalidCallback@-25298$errSecInvalidCertAuthority@-67826$errSecInvalidCertificateGroup@-67691$errSecInvalidCertificateRef@-67690$errSecInvalidContext@-67746$errSecInvalidDBList@-67681$errSecInvalidDBLocation@-67875$errSecInvalidData@-67673$errSecInvalidDatabaseBlob@-67598$errSecInvalidDigestAlgorithm@-67815$errSecInvalidEncoding@-67853$errSecInvalidExtendedKeyUsage@-67609$errSecInvalidFormType@-67831$errSecInvalidGUID@-67679$errSecInvalidHandle@-67680$errSecInvalidHandleUsage@-67668$errSecInvalidID@-67832$errSecInvalidIDLinkage@-67610$errSecInvalidIdentifier@-67833$errSecInvalidIndex@-67834$errSecInvalidIndexInfo@-67877$errSecInvalidInputVector@-67744$errSecInvalidItemRef@-25304$errSecInvalidKeyAttributeMask@-67738$errSecInvalidKeyBlob@-67599$errSecInvalidKeyFormat@-67742$errSecInvalidKeyHierarchy@-67713$errSecInvalidKeyLabel@-67740$errSecInvalidKeyRef@-67712$errSecInvalidKeyUsageForPolicy@-67608$errSecInvalidKeyUsageMask@-67736$errSecInvalidKeychain@-25295$errSecInvalidLoginName@-67813$errSecInvalidModifyMode@-67879$errSecInvalidName@-67689$errSecInvalidNetworkAddress@-67683$errSecInvalidNewOwner@-67878$errSecInvalidNumberOfFields@-67685$errSecInvalidOutputVector@-67745$errSecInvalidOwnerEdit@-25244$errSecInvalidPVC@-67708$errSecInvalidParsingModule@-67868$errSecInvalidPassthroughID@-67682$errSecInvalidPasswordRef@-25261$errSecInvalidPointer@-67675$errSecInvalidPolicyIdentifiers@-67835$errSecInvalidPrefsDomain@-25319$errSecInvalidQuery@-67693$errSecInvalidReason@-67837$errSecInvalidRecord@-67701$errSecInvalidRequestInputs@-67838$errSecInvalidRequestor@-67855$errSecInvalidResponseVector@-67839$errSecInvalidRoot@-67612$errSecInvalidSampleValue@-67703$errSecInvalidScope@-67706$errSecInvalidSearchRef@-25305$errSecInvalidServiceMask@-67717$errSecInvalidSignature@-67688$errSecInvalidStopOnPolicy@-67840$errSecInvalidSubServiceID@-67719$errSecInvalidSubjectKeyID@-67607$errSecInvalidSubjectName@-67655$errSecInvalidTimeString@-67836$errSecInvalidTrustSetting@-25242$errSecInvalidTrustSettings@-25262$errSecInvalidTuple@-67841$errSecInvalidTupleCredendtials@-67852$errSecInvalidTupleCredentials@-67852$errSecInvalidTupleGroup@-67850$errSecInvalidValidityPeriod@-67854$errSecInvalidValue@-67694$errSecItemNotFound@-25300$errSecKeyBlobTypeIncorrect@-67732$errSecKeyHeaderInconsistent@-67733$errSecKeyIsSensitive@-25258$errSecKeySizeNotAllowed@-25311$errSecKeyUsageIncorrect@-67731$errSecLibraryReferenceNotFound@-67715$errSecMDSError@-67674$errSecMemoryError@-67672$errSecMissingAlgorithmParms@-67771$errSecMissingAttributeAccessCredentials@-67797$errSecMissingAttributeBase@-67789$errSecMissingAttributeBlockSize@-67765$errSecMissingAttributeDLDBHandle@-67795$errSecMissingAttributeEffectiveBits@-67779$errSecMissingAttributeEndDate@-67783$errSecMissingAttributeInitVector@-67751$errSecMissingAttributeIterationCount@-67793$errSecMissingAttributeKey@-67749$errSecMissingAttributeKeyLength@-67763$errSecMissingAttributeKeyType@-67775$errSecMissingAttributeLabel@-67773$errSecMissingAttributeMode@-67777$errSecMissingAttributeOutputSize@-67767$errSecMissingAttributePadding@-67755$errSecMissingAttributePassphrase@-67761$errSecMissingAttributePrime@-67787$errSecMissingAttributePrivateKeyFormat@-67801$errSecMissingAttributePublicKeyFormat@-67799$errSecMissingAttributeRandom@-67757$errSecMissingAttributeRounds@-67769$errSecMissingAttributeSalt@-67753$errSecMissingAttributeSeed@-67759$errSecMissingAttributeStartDate@-67781$errSecMissingAttributeSubprime@-67791$errSecMissingAttributeSymmetricKeyFormat@-67803$errSecMissingAttributeVersion@-67785$errSecMissingAttributeWrappedKeyFormat@-67805$errSecMissingEntitlement@-34018$errSecMissingRequiredExtension@-67880$errSecMissingValue@-67871$errSecMobileMeCSRVerifyFailure@-67665$errSecMobileMeFailedConsistencyCheck@-67666$errSecMobileMeNoRequestPending@-67664$errSecMobileMeRequestAlreadyPending@-67663$errSecMobileMeRequestQueued@-67657$errSecMobileMeRequestRedirected@-67658$errSecMobileMeServerAlreadyExists@-67661$errSecMobileMeServerError@-67659$errSecMobileMeServerNotAvailable@-67660$errSecMobileMeServerServiceErr@-67662$errSecModuleManagerInitializeFailed@-67721$errSecModuleManagerNotFound@-67722$errSecModuleManifestVerifyFailed@-67678$errSecModuleNotLoaded@-67718$errSecMultipleExecSegments@-66995$errSecMultiplePrivKeys@-25259$errSecMultipleValuesUnsupported@-67842$errSecNetworkFailure@-67636$errSecNoAccessForItem@-25243$errSecNoBasicConstraints@-67604$errSecNoBasicConstraintsCA@-67605$errSecNoCertificateModule@-25313$errSecNoDefaultAuthority@-67844$errSecNoDefaultKeychain@-25307$errSecNoFieldValues@-67859$errSecNoPolicyModule@-25314$errSecNoStorageModule@-25312$errSecNoSuchAttr@-25303$errSecNoSuchClass@-25306$errSecNoSuchKeychain@-25294$errSecNoTrustSettings@-25263$errSecNotAvailable@-25291$errSecNotInitialized@-67667$errSecNotLoggedIn@-67729$errSecNotSigner@-26267$errSecNotTrusted@-67843$errSecOCSPBadRequest@-67631$errSecOCSPBadResponse@-67630$errSecOCSPNoSigner@-67640$errSecOCSPNotTrustedToAnchor@-67637$errSecOCSPResponderInternalError@-67642$errSecOCSPResponderMalformedReq@-67641$errSecOCSPResponderSignatureRequired@-67644$errSecOCSPResponderTryLater@-67643$errSecOCSPResponderUnauthorized@-67645$errSecOCSPResponseNonceMismatch@-67646$errSecOCSPSignatureError@-67639$errSecOCSPStatusUnrecognized@-67633$errSecOCSPUnavailable@-67632$errSecOpWr@-49$errSecOutputLengthError@-67725$errSecPVCAlreadyConfigured@-67707$errSecPVCReferentNotFound@-67669$errSecParam@-50$errSecPassphraseRequired@-25260$errSecPathLengthConstraintExceeded@-67611$errSecPkcs12VerifyFailure@-25264$errSecPolicyNotFound@-25241$errSecPrivilegeNotGranted@-67705$errSecPrivilegeNotSupported@-67726$errSecPublicKeyInconsistent@-67811$errSecQuerySizeUnknown@-67809$errSecQuotaExceeded@-67596$errSecReadOnly@-25292$errSecReadOnlyAttr@-25309$errSecRecordModified@-67638$errSecRejectedForm@-67845$errSecRequestDescriptor@-67856$errSecRequestLost@-67846$errSecRequestRejected@-67847$errSecResourceSignBadCertChainLength@-67652$errSecResourceSignBadExtKeyUsage@-67653$errSecRestrictedAPI@-34020$errSecSMIMEBadExtendedKeyUsage@-67624$errSecSMIMEBadKeyUsage@-67625$errSecSMIMEEmailAddressesNotFound@-67623$errSecSMIMEKeyUsageNotCritical@-67626$errSecSMIMENoEmailAddress@-67627$errSecSMIMESubjAltNameNotCritical@-67628$errSecSSLBadExtendedKeyUsage@-67629$errSecSelfCheckFailed@-67676$errSecServiceNotAvailable@-67585$errSecSigningTimeMissing@-67894$errSecStagedOperationInProgress@-67806$errSecStagedOperationNotStarted@-67807$errSecSuccess@0$errSecTagNotFound@-67692$errSecTimestampAddInfoNotAvailable@-67892$errSecTimestampBadAlg@-67886$errSecTimestampBadDataFormat@-67888$errSecTimestampBadRequest@-67887$errSecTimestampInvalid@-67883$errSecTimestampMissing@-67882$errSecTimestampNotTrusted@-67884$errSecTimestampRejection@-67895$errSecTimestampRevocationNotification@-67898$errSecTimestampRevocationWarning@-67897$errSecTimestampServiceNotAvailable@-67885$errSecTimestampSystemFailure@-67893$errSecTimestampTimeNotAvailable@-67889$errSecTimestampUnacceptedExtension@-67891$errSecTimestampUnacceptedPolicy@-67890$errSecTimestampWaiting@-67896$errSecTrustNotAvailable@-25245$errSecTrustSettingDeny@-67654$errSecUnimplemented@-4$errSecUnknownCRLExtension@-67619$errSecUnknownCertExtension@-67618$errSecUnknownCriticalExtensionFlag@-67603$errSecUnknownFormat@-25257$errSecUnknownQualifiedCertStatement@-67656$errSecUnknownTag@-67687$errSecUnsupportedAddressType@-67848$errSecUnsupportedFieldFormat@-67860$errSecUnsupportedFormat@-25256$errSecUnsupportedIndexInfo@-67861$errSecUnsupportedKeyAttributeMask@-67739$errSecUnsupportedKeyFormat@-67734$errSecUnsupportedKeyLabel@-67741$errSecUnsupportedKeySize@-67735$errSecUnsupportedKeyUsageMask@-67737$errSecUnsupportedLocality@-67862$errSecUnsupportedNumAttributes@-67863$errSecUnsupportedNumIndexes@-67864$errSecUnsupportedNumRecordTypes@-67865$errSecUnsupportedNumSelectionPreds@-67873$errSecUnsupportedOperator@-67874$errSecUnsupportedQueryLimits@-67872$errSecUnsupportedService@-67849$errSecUnsupportedVectorOfBuffers@-67743$errSecUserCanceled@-128$errSecVerificationFailure@-67686$errSecVerifyActionFailed@-67825$errSecVerifyFailed@-67808$errSecWrPerm@-61$errSecWrongSecVersion@-25310$errSecureDownloadInvalidDownload@-20053$errSecureDownloadInvalidTicket@-20052$errSessionAuthorizationDenied@-60502$errSessionInternal@-60008$errSessionInvalidAttributes@-60501$errSessionInvalidFlags@-60011$errSessionInvalidId@-60500$errSessionSuccess@0$errSessionValueNotSet@-60503$kAlwaysAuthenticate@1$kAuthorizationExternalFormLength@32$kAuthorizationFlagCanNotPreAuthorize@1$kAuthorizationFlagDefaults@0$kAuthorizationFlagDestroyRights@8$kAuthorizationFlagExtendRights@2$kAuthorizationFlagInteractionAllowed@1$kAuthorizationFlagNoData@1048576$kAuthorizationFlagPartialRights@4$kAuthorizationFlagPreAuthorize@16$kAuthorizationResultAllow@0$kAuthorizationResultDeny@1$kAuthorizationResultUndefined@2$kAuthorizationResultUserCanceled@3$kCMSAttrAppleCodesigningHashAgility@16$kCMSAttrAppleCodesigningHashAgilityV2@32$kCMSAttrAppleExpirationTime@64$kCMSAttrNone@0$kCMSAttrSigningTime@8$kCMSAttrSmimeCapabilities@1$kCMSAttrSmimeEncryptionKeyPrefs@2$kCMSAttrSmimeMSEncryptionKeyPrefs@4$kCMSCertificateChain@2$kCMSCertificateChainWithRoot@3$kCMSCertificateChainWithRootOrFail@4$kCMSCertificateNone@0$kCMSCertificateSignerOnly@1$kCMSSignerInvalidCert@4$kCMSSignerInvalidIndex@5$kCMSSignerInvalidSignature@3$kCMSSignerNeedsDetachedContent@2$kCMSSignerUnsigned@0$kCMSSignerValid@1$kDTLSProtocol1@9$kDTLSProtocol12@11$kNeverAuthenticate@0$kSSLAborted@4$kSSLCiphersuiteGroupATS@3$kSSLCiphersuiteGroupATSCompatibility@4$kSSLCiphersuiteGroupCompatibility@1$kSSLCiphersuiteGroupDefault@0$kSSLCiphersuiteGroupLegacy@2$kSSLClientCertNone@0$kSSLClientCertRejected@3$kSSLClientCertRequested@1$kSSLClientCertSent@2$kSSLClientSide@1$kSSLClosed@3$kSSLConnected@2$kSSLDatagramType@1$kSSLHandshake@1$kSSLIdle@0$kSSLProtocol2@1$kSSLProtocol3@2$kSSLProtocol3Only@3$kSSLProtocolAll@6$kSSLProtocolUnknown@0$kSSLServerSide@0$kSSLSessionOptionAllowRenegotiation@8$kSSLSessionOptionAllowServerIdentityChange@5$kSSLSessionOptionBreakOnCertRequested@1$kSSLSessionOptionBreakOnClientAuth@2$kSSLSessionOptionBreakOnClientHello@7$kSSLSessionOptionBreakOnServerAuth@0$kSSLSessionOptionEnableSessionTickets@9$kSSLSessionOptionFallback@6$kSSLSessionOptionFalseStart@3$kSSLSessionOptionSendOneByteRecord@4$kSSLStreamType@0$kSec3DES192@192$kSecAES128@128$kSecAES192@192$kSecAES256@256$kSecAccessControlAnd@32768$kSecAccessControlApplicationPassword@2147483648$kSecAccessControlBiometryAny@2$kSecAccessControlBiometryCurrentSet@8$kSecAccessControlDevicePasscode@16$kSecAccessControlOr@16384$kSecAccessControlPrivateKeyUsage@1073741824$kSecAccessControlTouchIDAny@2$kSecAccessControlTouchIDCurrentSet@8$kSecAccessControlUserPresence@1$kSecAccessControlWatch@32$kSecAccountItemAttr@1633903476$kSecAddEvent@3$kSecAddEventMask@8$kSecAddressItemAttr@1633969266$kSecAlias@1634494835$kSecAppleSharePasswordItemClass@1634953328$kSecAuthenticationTypeAny@0$kSecAuthenticationTypeDPA@1633775716$kSecAuthenticationTypeDefault@1953261156$kSecAuthenticationTypeHTMLForm@1836216166$kSecAuthenticationTypeHTTPBasic@1886680168$kSecAuthenticationTypeHTTPDigest@1685353576$kSecAuthenticationTypeItemAttr@1635023216$kSecAuthenticationTypeMSN@1634628461$kSecAuthenticationTypeNTLM@1835824238$kSecAuthenticationTypeRPA@1633775730$kSecCSAllowNetworkAccess@65536$kSecCSApplyEmbeddedPolicy@33554432$kSecCSBasicValidateOnly@6$kSecCSCalculateCMSDigest@64$kSecCSCheckAllArchitectures@1$kSecCSCheckGatekeeperArchitectures@65$kSecCSCheckNestedCode@8$kSecCSCheckTrustedAnchors@134217728$kSecCSConsiderExpiration@2147483648$kSecCSContentInformation@16$kSecCSDedicatedHost@1$kSecCSDefaultFlags@0$kSecCSDoNotValidateExecutable@2$kSecCSDoNotValidateResources@4$kSecCSDynamicInformation@8$kSecCSEnforceRevocationChecks@1073741824$kSecCSFastExecutableValidation@131072$kSecCSFullReport@32$kSecCSGenerateGuestHash@2$kSecCSInternalInformation@1$kSecCSNoNetworkAccess@536870912$kSecCSQuickCheck@67108864$kSecCSReportProgress@268435456$kSecCSRequirementInformation@4$kSecCSRestrictSidebandData@512$kSecCSRestrictSymlinks@128$kSecCSRestrictToAppLike@256$kSecCSSigningInformation@2$kSecCSSingleThreaded@4096$kSecCSSkipResourceDirectory@32$kSecCSStrictValidate@16$kSecCSUseAllArchitectures@1$kSecCSUseSoftwareSigningCert@1024$kSecCSValidatePEH@2048$kSecCertificateEncoding@1667591779$kSecCertificateItemClass@2147487744$kSecCertificateType@1668577648$kSecCodeSignatureAdhoc@2$kSecCodeSignatureEnforcement@4096$kSecCodeSignatureForceExpiration@1024$kSecCodeSignatureForceHard@256$kSecCodeSignatureForceKill@512$kSecCodeSignatureHashSHA1@1$kSecCodeSignatureHashSHA256@2$kSecCodeSignatureHashSHA256Truncated@3$kSecCodeSignatureHashSHA384@4$kSecCodeSignatureHashSHA512@5$kSecCodeSignatureHost@1$kSecCodeSignatureLibraryValidation@8192$kSecCodeSignatureLinkerSigned@131072$kSecCodeSignatureNoHash@0$kSecCodeSignatureRestrict@2048$kSecCodeSignatureRuntime@65536$kSecCodeStatusDebugged@268435456$kSecCodeStatusHard@256$kSecCodeStatusKill@512$kSecCodeStatusPlatform@67108864$kSecCodeStatusValid@1$kSecCommentItemAttr@1768123764$kSecCreationDateItemAttr@1667522932$kSecCreatorItemAttr@1668445298$kSecCredentialTypeDefault@0$kSecCredentialTypeNoUI@2$kSecCredentialTypeWithUI@1$kSecCrlEncoding@1668443747$kSecCrlType@1668445296$kSecCustomIconItemAttr@1668641641$kSecDataAccessEvent@10$kSecDataAccessEventMask@1024$kSecDefaultChangedEvent@9$kSecDefaultChangedEventMask@512$kSecDefaultKeySize@0$kSecDeleteEvent@4$kSecDeleteEventMask@16$kSecDescriptionItemAttr@1684370275$kSecDesignatedRequirementType@3$kSecEveryEventMask@4294967295$kSecFormatBSAFE@3$kSecFormatNetscapeCertSequence@13$kSecFormatOpenSSL@1$kSecFormatPEMSequence@10$kSecFormatPKCS12@12$kSecFormatPKCS7@11$kSecFormatRawKey@4$kSecFormatSSH@2$kSecFormatSSHv2@14$kSecFormatUnknown@0$kSecFormatWrappedLSH@8$kSecFormatWrappedOpenSSL@6$kSecFormatWrappedPKCS8@5$kSecFormatWrappedSSH@7$kSecFormatX509Cert@9$kSecGenericItemAttr@1734700641$kSecGenericPasswordItemClass@1734700656$kSecGuestRequirementType@2$kSecHonorRoot@256$kSecHostRequirementType@1$kSecInternetPasswordItemClass@1768842612$kSecInvalidRequirementType@6$kSecInvisibleItemAttr@1768846953$kSecItemPemArmour@1$kSecItemTypeAggregate@5$kSecItemTypeCertificate@4$kSecItemTypePrivateKey@1$kSecItemTypePublicKey@2$kSecItemTypeSessionKey@3$kSecItemTypeUnknown@0$kSecKeyAlias@2$kSecKeyAlwaysSensitive@15$kSecKeyApplicationTag@7$kSecKeyDecrypt@19$kSecKeyDerive@20$kSecKeyEffectiveKeySize@11$kSecKeyEncrypt@18$kSecKeyEndDate@13$kSecKeyExtractable@16$kSecKeyImportOnlyOne@1$kSecKeyKeyClass@0$kSecKeyKeyCreator@8$kSecKeyKeySizeInBits@10$kSecKeyKeyType@9$kSecKeyLabel@6$kSecKeyModifiable@5$kSecKeyNeverExtractable@17$kSecKeyNoAccessControl@4$kSecKeyOperationTypeDecrypt@3$kSecKeyOperationTypeEncrypt@2$kSecKeyOperationTypeKeyExchange@4$kSecKeyOperationTypeSign@0$kSecKeyOperationTypeVerify@1$kSecKeyPermanent@3$kSecKeyPrintName@1$kSecKeyPrivate@4$kSecKeySecurePassphrase@2$kSecKeySensitive@14$kSecKeySign@21$kSecKeySignRecover@23$kSecKeyStartDate@12$kSecKeyUnwrap@26$kSecKeyUsageAll@2147483647$kSecKeyUsageCRLSign@64$kSecKeyUsageContentCommitment@2$kSecKeyUsageCritical@2147483648$kSecKeyUsageDataEncipherment@8$kSecKeyUsageDecipherOnly@256$kSecKeyUsageDigitalSignature@1$kSecKeyUsageEncipherOnly@128$kSecKeyUsageKeyAgreement@16$kSecKeyUsageKeyCertSign@32$kSecKeyUsageKeyEncipherment@4$kSecKeyUsageNonRepudiation@2$kSecKeyUsageUnspecified@0$kSecKeyVerify@22$kSecKeyVerifyRecover@24$kSecKeyWrap@25$kSecKeychainListChangedEvent@11$kSecKeychainListChangedMask@2048$kSecKeychainPromptInvalid@64$kSecKeychainPromptInvalidAct@128$kSecKeychainPromptRequirePassphase@1$kSecKeychainPromptUnsigned@16$kSecKeychainPromptUnsignedAct@32$kSecLabelItemAttr@1818321516$kSecLibraryRequirementType@4$kSecLockEvent@1$kSecLockEventMask@2$kSecMatchBits@3$kSecModDateItemAttr@1835295092$kSecNegativeItemAttr@1852139361$kSecNoGuest@0$kSecPaddingNone@0$kSecPaddingOAEP@2$kSecPaddingPKCS1@1$kSecPaddingPKCS1MD2@32768$kSecPaddingPKCS1MD5@32769$kSecPaddingPKCS1SHA1@32770$kSecPaddingPKCS1SHA224@32771$kSecPaddingPKCS1SHA256@32772$kSecPaddingPKCS1SHA384@32773$kSecPaddingPKCS1SHA512@32774$kSecPaddingSigRaw@16384$kSecPasswordChangedEvent@6$kSecPasswordChangedEventMask@64$kSecPathItemAttr@1885434984$kSecPluginRequirementType@5$kSecPortItemAttr@1886351988$kSecPreferencesDomainCommon@2$kSecPreferencesDomainDynamic@3$kSecPreferencesDomainSystem@1$kSecPreferencesDomainUser@0$kSecPrivateKeyItemClass@16$kSecProtocolItemAttr@1886675820$kSecProtocolTypeAFP@1634103328$kSecProtocolTypeAny@0$kSecProtocolTypeAppleTalk@1635019883$kSecProtocolTypeCIFS@1667851891$kSecProtocolTypeCVSpserver@1668707184$kSecProtocolTypeDAAP@1684103536$kSecProtocolTypeEPPC@1701867619$kSecProtocolTypeFTP@1718906912$kSecProtocolTypeFTPAccount@1718906977$kSecProtocolTypeFTPProxy@1718907000$kSecProtocolTypeFTPS@1718906995$kSecProtocolTypeHTTP@1752462448$kSecProtocolTypeHTTPProxy@1752461432$kSecProtocolTypeHTTPS@1752461427$kSecProtocolTypeHTTPSProxy@1752462200$kSecProtocolTypeIMAP@1768776048$kSecProtocolTypeIMAPS@1768779891$kSecProtocolTypeIPP@1768976416$kSecProtocolTypeIRC@1769104160$kSecProtocolTypeIRCS@1769104243$kSecProtocolTypeLDAP@1818517872$kSecProtocolTypeLDAPS@1818521715$kSecProtocolTypeNNTP@1852732528$kSecProtocolTypeNNTPS@1853124723$kSecProtocolTypePOP3@1886351411$kSecProtocolTypePOP3S@1886351475$kSecProtocolTypeRTSP@1920234352$kSecProtocolTypeRTSPProxy@1920234360$kSecProtocolTypeSMB@1936548384$kSecProtocolTypeSMTP@1936553072$kSecProtocolTypeSOCKS@1936685088$kSecProtocolTypeSSH@1936943136$kSecProtocolTypeSVN@1937141280$kSecProtocolTypeTelnet@1952803950$kSecProtocolTypeTelnetS@1952803955$kSecPublicKeyItemClass@15$kSecRSAMax@4096$kSecRSAMin@1024$kSecReadPermStatus@2$kSecRequirementTypeCount@6$kSecRevocationCRLMethod@2$kSecRevocationNetworkAccessDisabled@16$kSecRevocationOCSPMethod@1$kSecRevocationPreferCRL@4$kSecRevocationRequirePositiveResponse@8$kSecRevocationUseAnyAvailableMethod@3$kSecScriptCodeItemAttr@1935897200$kSecSecurityDomainItemAttr@1935961454$kSecServerItemAttr@1936881266$kSecServiceItemAttr@1937138533$kSecSignatureItemAttr@1936943463$kSecSymmetricKeyItemClass@17$kSecTransformErrorAbortInProgress@19$kSecTransformErrorAborted@20$kSecTransformErrorAttributeNotFound@1$kSecTransformErrorInvalidAlgorithm@6$kSecTransformErrorInvalidConnection@15$kSecTransformErrorInvalidInput@10$kSecTransformErrorInvalidInputDictionary@5$kSecTransformErrorInvalidLength@7$kSecTransformErrorInvalidOperation@2$kSecTransformErrorInvalidType@8$kSecTransformErrorMissingParameter@14$kSecTransformErrorMoreThanOneOutput@4$kSecTransformErrorNameAlreadyRegistered@11$kSecTransformErrorNotInitializedCorrectly@3$kSecTransformErrorUnsupportedAttribute@12$kSecTransformInvalidArgument@21$kSecTransformInvalidOverride@17$kSecTransformMetaAttributeCanCycle@7$kSecTransformMetaAttributeDeferred@5$kSecTransformMetaAttributeExternalize@8$kSecTransformMetaAttributeHasInboundConnection@10$kSecTransformMetaAttributeHasOutboundConnections@9$kSecTransformMetaAttributeName@1$kSecTransformMetaAttributeRef@2$kSecTransformMetaAttributeRequired@3$kSecTransformMetaAttributeRequiresOutboundConnection@4$kSecTransformMetaAttributeStream@6$kSecTransformMetaAttributeValue@0$kSecTransformOperationNotSupportedOnGroup@13$kSecTransformTransformIsExecuting@16$kSecTransformTransformIsNotRegistered@18$kSecTrustOptionAllowExpired@1$kSecTrustOptionAllowExpiredRoot@8$kSecTrustOptionFetchIssuerFromNet@4$kSecTrustOptionImplicitAnchors@64$kSecTrustOptionLeafIsCA@2$kSecTrustOptionRequireRevPerCert@16$kSecTrustOptionUseTrustSettings@32$kSecTrustResultConfirm@2$kSecTrustResultDeny@3$kSecTrustResultFatalTrustFailure@6$kSecTrustResultInvalid@0$kSecTrustResultOtherError@7$kSecTrustResultProceed@1$kSecTrustResultRecoverableTrustFailure@5$kSecTrustResultUnspecified@4$kSecTrustSettingsChangedEvent@12$kSecTrustSettingsChangedEventMask@4096$kSecTrustSettingsDefaultRootCertSetting@-1$kSecTrustSettingsDomainAdmin@1$kSecTrustSettingsDomainSystem@2$kSecTrustSettingsDomainUser@0$kSecTrustSettingsKeyUseAny@4294967295$kSecTrustSettingsKeyUseEnDecryptData@2$kSecTrustSettingsKeyUseEnDecryptKey@4$kSecTrustSettingsKeyUseKeyExchange@32$kSecTrustSettingsKeyUseSignCert@8$kSecTrustSettingsKeyUseSignRevocation@16$kSecTrustSettingsKeyUseSignature@1$kSecTrustSettingsResultDeny@3$kSecTrustSettingsResultInvalid@0$kSecTrustSettingsResultTrustAsRoot@2$kSecTrustSettingsResultTrustRoot@1$kSecTrustSettingsResultUnspecified@4$kSecTypeItemAttr@1954115685$kSecUnlockEvent@2$kSecUnlockEventMask@4$kSecUnlockStateStatus@1$kSecUpdateEvent@5$kSecUpdateEventMask@32$kSecUseOnlyGID@2$kSecUseOnlyUID@1$kSecVolumeItemAttr@1986817381$kSecWritePermStatus@4$kSecp192r1@192$kSecp256r1@256$kSecp384r1@384$kSecp521r1@521$kSecureDownloadDoNotEvaluateSigner@0$kSecureDownloadEvaluateSigner@1$kSecureDownloadFailEvaluation@2$kTLSProtocol1@4$kTLSProtocol11@7$kTLSProtocol12@8$kTLSProtocol13@10$kTLSProtocol1Only@5$kTLSProtocolMaxSupported@999$kTryAuthenticate@2$noSecuritySession@0$sessionHasGraphicAccess@16$sessionHasTTY@32$sessionIsRemote@4096$sessionIsRoot@1$sessionKeepCurrentBootstrap@32768$tls_ciphersuite_AES_128_GCM_SHA256@4865$tls_ciphersuite_AES_256_GCM_SHA384@4866$tls_ciphersuite_CHACHA20_POLY1305_SHA256@4867$tls_ciphersuite_ECDHE_ECDSA_WITH_3DES_EDE_CBC_SHA@49160$tls_ciphersuite_ECDHE_ECDSA_WITH_AES_128_CBC_SHA@49161$tls_ciphersuite_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256@49187$tls_ciphersuite_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256@49195$tls_ciphersuite_ECDHE_ECDSA_WITH_AES_256_CBC_SHA@49162$tls_ciphersuite_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384@49188$tls_ciphersuite_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384@49196$tls_ciphersuite_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256@52393$tls_ciphersuite_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA@49170$tls_ciphersuite_ECDHE_RSA_WITH_AES_128_CBC_SHA@49171$tls_ciphersuite_ECDHE_RSA_WITH_AES_128_CBC_SHA256@49191$tls_ciphersuite_ECDHE_RSA_WITH_AES_128_GCM_SHA256@49199$tls_ciphersuite_ECDHE_RSA_WITH_AES_256_CBC_SHA@49172$tls_ciphersuite_ECDHE_RSA_WITH_AES_256_CBC_SHA384@49192$tls_ciphersuite_ECDHE_RSA_WITH_AES_256_GCM_SHA384@49200$tls_ciphersuite_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256@52392$tls_ciphersuite_RSA_WITH_3DES_EDE_CBC_SHA@10$tls_ciphersuite_RSA_WITH_AES_128_CBC_SHA@47$tls_ciphersuite_RSA_WITH_AES_128_CBC_SHA256@60$tls_ciphersuite_RSA_WITH_AES_128_GCM_SHA256@156$tls_ciphersuite_RSA_WITH_AES_256_CBC_SHA@53$tls_ciphersuite_RSA_WITH_AES_256_CBC_SHA256@61$tls_ciphersuite_RSA_WITH_AES_256_GCM_SHA384@157$tls_ciphersuite_group_ats@3$tls_ciphersuite_group_ats_compatibility@4$tls_ciphersuite_group_compatibility@1$tls_ciphersuite_group_default@0$tls_ciphersuite_group_legacy@2$tls_protocol_version_DTLSv10@65279$tls_protocol_version_DTLSv12@65277$tls_protocol_version_TLSv10@769$tls_protocol_version_TLSv11@770$tls_protocol_version_TLSv12@771$tls_protocol_version_TLSv13@772$"""
misc.update(
    {
        "SessionCreationFlags": NewType("SessionCreationFlags", int),
        "tls_ciphersuite_group_t": NewType("tls_ciphersuite_group_t", int),
        "SecTrustResultType": NewType("SecTrustResultType", int),
        "tls_ciphersuite_t": NewType("tls_ciphersuite_t", int),
        "SecItemAttr": NewType("SecItemAttr", int),
        "SecKeychainEventMask": NewType("SecKeychainEventMask", int),
        "SecItemClass": NewType("SecItemClass", int),
        "SecCSDigestAlgorithm": NewType("SecCSDigestAlgorithm", int),
        "CMSSignedAttributes": NewType("CMSSignedAttributes", int),
        "SecTrustSettingsKeyUsage": NewType("SecTrustSettingsKeyUsage", int),
        "CMSCertificateChainMode": NewType("CMSCertificateChainMode", int),
        "SecAccessControlCreateFlags": NewType("SecAccessControlCreateFlags", int),
        "SecCSFlags": NewType("SecCSFlags", int),
        "SecCodeSignatureFlags": NewType("SecCodeSignatureFlags", int),
        "CMSSignerStatus": NewType("CMSSignerStatus", int),
        "SecPreferencesDomain": NewType("SecPreferencesDomain", int),
        "tls_protocol_version_t": NewType("tls_protocol_version_t", int),
        "SessionAttributeBits": NewType("SessionAttributeBits", int),
        "SecRequirementType": NewType("SecRequirementType", int),
        "SecAuthenticationType": NewType("SecAuthenticationType", int),
        "SSLCiphersuiteGroup": NewType("SSLCiphersuiteGroup", int),
        "SecTrustSettingsResult": NewType("SecTrustSettingsResult", int),
        "SecProtocolType": NewType("SecProtocolType", int),
        "SSLProtocol": NewType("SSLProtocol", int),
        "SecKeyUsage": NewType("SecKeyUsage", int),
        "SecKeychainEvent": NewType("SecKeychainEvent", int),
        "SecCodeStatus": NewType("SecCodeStatus", int),
        "SecTrustSettingsDomain": NewType("SecTrustSettingsDomain", int),
        "SecTransformMetaAttributeType": NewType("SecTransformMetaAttributeType", int),
        "SecTrustOptionFlags": NewType("SecTrustOptionFlags", int),
    }
)
misc.update(
    {
        "kAuthorizationComment": b"comment",
        "kSecTrustSettingsAllowedError": "kSecTrustSettingsAllowedError",
        "kSecTrustSettingsApplication": "kSecTrustSettingsApplication",
        "kSecTrustSettingsResult": "kSecTrustSettingsResult",
        "kAuthorizationEnvironmentIcon": b"icon",
        "kAuthorizationPamResult": b"pam_result",
        "kAuthorizationRuleClassDeny": b"deny",
        "kAuthorizationEnvironmentUsername": b"username",
        "kSecTrustSettingsKeyUsage": "kSecTrustSettingsKeyUsage",
        "kAuthorizationRuleIsAdmin": b"is-admin",
        "kAuthorizationRuleClassAllow": b"allow",
        "kAuthorizationEnvironmentPassword": b"password",
        "kAuthorizationRuleAuthenticateAsAdmin": b"authenticate-admin",
        "kSecTrustSettingsPolicyString": "kSecTrustSettingsPolicyString",
        "kAuthorizationEnvironmentPrompt": b"prompt",
        "kAuthorizationRightRule": b"rule",
        "kAuthorizationRuleAuthenticateAsSessionUser": b"authenticate-session-owner",
        "kAuthorizationFlags": b"flags",
        "kAuthorizationEnvironmentShared": b"shared",
        "kSecTrustSettingsPolicy": "kSecTrustSettingsPolicy",
        "kAuthorizationRightExecute": b"system.privilege.admin",
    }
)
functions = {
    "CMSEncoderGetCertificateChainMode": (b"i@o^I",),
    "SecKeyGeneratePair": (
        b"i@o^@o^@",
        "",
        {
            "arguments": {
                1: {"already_cfretained": True},
                2: {"already_cfretained": True},
            }
        },
    ),
    "SecCodeCopyPath": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecCertificateCopySerialNumber": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecKeyIsAlgorithmSupported": (sel32or64(b"Z@i@", b"Z@q@"),),
    "SecTrustSetPolicies": (b"i@@",),
    "SecTrustCopyKey": (
        b"^{__SecKey=}^{__SecTrust=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SSLSetError": (b"i@i",),
    "SecTransformCustomSetAttribute": (b"@^{OpaqueSecTransformImplementation=}@q@",),
    "SSLGetSessionOption": (b"i@io^Z",),
    "SecStaticCodeCreateWithPath": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecTrustGetCertificateAtIndex": (b"@@q",),
    "SecTransformSetTransformAction": (
        b"@^{OpaqueSecTransformImplementation=}@@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"@"},
                        "arguments": {0: {"type": "^v"}},
                    }
                }
            }
        },
    ),
    "sec_protocol_options_set_tls_tickets_enabled": (b"vBB",),
    "SSLGetSessionState": (b"i@o^i",),
    "SecItemImport": (
        b"i@@N^IN^IIn^{_SecItemImportExportKeyParameters=II@@@@@@}@o^@",
        "",
        {"arguments": {7: {"already_cfretained": True}}},
    ),
    "SSLGetMaxDatagramRecordSize": (b"i@o^L",),
    "sec_protocol_options_set_tls_ocsp_enabled": (b"vBB",),
    "SecTrustEvaluate": (b"i@o^I",),
    "CMSDecoderIsContentEncrypted": (b"i@o^Z",),
    "SecTaskCreateFromSelf": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "SecureDownloadCopyCreationDate": (
        b"i^{OpaqueSecureDownload=}o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "SecTransformSetAttributeAction": (
        b"@^{OpaqueSecTransformImplementation=}@@@?",
        "",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"@"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "sec_certificate_copy_ref": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "SSLCopyDistinguishedNames": (
        b"i@o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "SecTrustSetExceptions": (b"B@@",),
    "SecItemAdd": (b"i@o^@", "", {"arguments": {1: {"already_cfretained": True}}}),
    "SecKeychainItemCopyKeychain": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "sec_protocol_metadata_get_server_name": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "SecPolicyCreateRevocation": (b"@Q", "", {"retval": {"already_cfretained": True}}),
    "SecKeyCreateEncryptedData": (
        b"@@@@o^@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecCertificateCopyNormalizedSubjectContent": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecKeyCreateSignature": (b"@@@@o^@", "", {"retval": {"already_cfretained": True}}),
    "CMSDecoderCreate": (
        b"io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {0: {"already_cfretained": True}},
        },
    ),
    "CMSDecoderCopyAllCerts": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "sec_protocol_options_add_tls_ciphersuite_group": (b"v@S",),
    "SecDigestTransformCreate": (
        b"@@qo^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SSLSetEncryptionCertificate": (b"i@@",),
    "SecHostCreateGuest": (b"iII@@Io^I", "", {"retval": {"already_cfretained": True}}),
    "SecTrustSettingsCopyCertificates": (
        b"iIo^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecKeychainUnlock": (
        b"i@In^vZ",
        "",
        {"arguments": {2: {"c_array_length_in_arg": 1}}},
    ),
    "SSLSetSessionTicketsEnabled": (b"i@Z",),
    "SecHostSelectGuest": (b"iII",),
    "AuthorizationCopyPrivilegedReference": (b"io^^{AuthorizationOpaqueRef=}",),
    "CMSDecoderSetDetachedContent": (b"i@@",),
    "sec_identity_create": (b"@@", "", {"retval": {"already_retained": True}}),
    "SSLAddDistinguishedName": (
        b"i@n^vL",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "SecKeychainItemCopyFromPersistentReference": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecTransformCopyExternalRepresentation": (
        b"@@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "sec_protocol_options_append_tls_ciphersuite_group": (b"v@S",),
    "SecStaticCodeCheckValidityWithErrors": (
        b"i@I@o^@",
        "",
        {
            "arguments": {
                3: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            }
        },
    ),
    "SSLGetNegotiatedProtocolVersion": (b"i@o^i",),
    "sec_protocol_metadata_access_distinguished_names": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    },
                    "callable_retained": True,
                    "block": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}},
                    },
                }
            }
        },
    ),
    "SecTransformPushbackAttribute": (b"@^{OpaqueSecTransformImplementation=}@@",),
    "SecAccessCreateWithOwnerAndACL": (
        b"@III@o^@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecTrustCopyResult": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "CMSDecoderCopySignerSigningTime": (
        b"i@Lo^d",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecTrustSetNetworkFetchAllowed": (b"i@Z",),
    "SSLSetCertificate": (b"i@@",),
    "SecACLSetContents": (b"i@@@S",),
    "sec_protocol_options_append_tls_ciphersuite": (b"v@@",),
    "SecTrustGetCertificateCount": (b"q@",),
    "SecPKCS12Import": (
        b"i@@o^@",
        "",
        {"arguments": {2: {"already_cfretained": True}}},
    ),
    "sec_protocol_options_set_peer_authentication_optional": (b"v@B",),
    "SecTransformSetAttribute": (
        b"Z@@@o^@",
        "",
        {
            "arguments": {
                3: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            }
        },
    ),
    "SecACLGetTypeID": (sel32or64(b"I", b"Q"),),
    "SecTrustSettingsSetTrustSettings": (b"i@I@",),
    "SecKeyCopyExternalRepresentation": (
        b"@@o^@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecTransformCreateGroupTransform": (
        b"@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CMSDecoderSetSearchKeychain": (b"i@@",),
    "SecTrustedApplicationSetData": (b"i@@",),
    "SSLSetSessionOption": (b"i@iZ",),
    "sec_protocol_options_set_peer_authentication_required": (b"vBB",),
    "SecKeychainSetPreferenceDomain": (b"ii",),
    "SecTransformCreateFromExternalRepresentation": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SSLGetBufferedReadSize": (b"i@o^L",),
    "SecTrustSetVerifyDate": (b"i@@",),
    "sec_trust_copy_ref": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "SecKeychainItemCreateFromContent": (
        b"iI^{SecKeychainAttributeList=I^{SecKeychainAttribute=II^v}}I^v^{__SecKeychain=}^{__SecAccess=}^^{__SecKeychainItem=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SSLContextGetTypeID": (sel32or64(b"I", b"Q"),),
    "SessionCreate": (b"iII", "", {"retval": {"already_cfretained": True}}),
    "sec_identity_access_certificates": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    },
                    "block": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}},
                    },
                }
            }
        },
    ),
    "SecAccessCopyOwnerAndACL": (
        b"i@o^Io^Io^Io^@",
        "",
        {"arguments": {4: {"already_cfretained": True}}},
    ),
    "SecPolicyCreateWithProperties": (
        b"@@@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecIdentitySearchGetTypeID": (b"Q",),
    "SecKeychainLockAll": (b"i",),
    "SSLGetPeerDomainName": (
        b"i@o^tN^L",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "SecTaskGetCodeSignStatus": (b"I^{__SecTask=}",),
    "sec_protocol_metadata_access_ocsp_response": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    },
                    "block": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}},
                    },
                }
            }
        },
    ),
    "SecACLCopyContents": (
        b"i@o^@o^@o^S",
        "",
        {
            "arguments": {
                1: {"already_cfretained": True},
                2: {"already_cfretained": True},
            }
        },
    ),
    "SecKeychainGetDLDBHandle": (b"i^{__SecKeychain=}^{cssm_dl_db_handle=qq}",),
    "SecCodeMapMemory": (b"i@I",),
    "CMSDecoderCopyContent": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecAccessCreate": (
        b"i@@o^@",
        "",
        {"arguments": {2: {"already_cfretained": True}}},
    ),
    "SecTransformExecute": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecCertificateCopyEmailAddresses": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "AuthorizationMakeExternalForm": (
        b"i^{AuthorizationOpaqueRef=}o^{_AuthorizationExternalForm=[32C]}",
    ),
    "SecCodeCheckValidityWithErrors": (
        b"i@I@o^@",
        "",
        {
            "arguments": {
                3: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            }
        },
    ),
    "SecCodeCopyDesignatedRequirement": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecTransformNoData": (b"@",),
    "SecTransformRegister": (
        b"Z^{__CFString=}^?^^{__CFError=}",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {
                            0: {"type": b"^{__CFString=}"},
                            1: {"type": b"@"},
                            2: {"type": b"^{OpaqueSecTransformImplementation=}"},
                        },
                    }
                },
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                },
            }
        },
    ),
    "SecCodeCopyStaticCode": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "CMSEncoderAddSignedAttributes": (b"i@I",),
    "SecIdentityCopySystemIdentity": (
        b"i@o^@o^@",
        "",
        {
            "arguments": {
                1: {"already_cfretained": True},
                2: {"already_cfretained": True},
            }
        },
    ),
    "SecureDownloadGetDownloadSize": (b"i^{OpaqueSecureDownload=}o^q",),
    "SecKeychainItemDelete": (b"i@",),
    "SecStaticCodeCreateWithPathAndAttributes": (
        b"i@I@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"already_cfretained": True}},
        },
    ),
    "sec_identity_create_with_certificates": (
        b"@@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "SSLCopyPeerTrust": (
        b"i@o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "SecKeyVerifySignature": (b"Z@@@@o^@",),
    "AuthorizationRightGet": (
        b"i^t^@",
        "",
        {
            "arguments": {
                0: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                1: {"already_retained": True, "type_modifier": "o"},
            }
        },
    ),
    "SecDecryptTransformCreate": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecCertificateCopyNormalizedIssuerContent": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecPolicyCreateBasicX509": (b"@", "", {"retval": {"already_cfretained": True}}),
    "sec_protocol_options_set_tls_false_start_enabled": (b"vBB",),
    "SecKeychainLock": (b"i@",),
    "SecTrustGetNetworkFetchAllowed": (b"i@o^Z",),
    "SecureDownloadCreateWithTicket": (
        b"i@^?^v^?^vo^^{OpaqueSecureDownload=}",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"i"},
                        "arguments": {0: {"type": "@"}, 1: {"type": "^v"}},
                    },
                    "callable_retained": True,
                },
                3: {
                    "callable": {
                        "retval": {"type": b"i"},
                        "arguments": {
                            0: {"type": "@"},
                            1: {"type": "i"},
                            2: {"type": "^v"},
                        },
                    },
                    "callable_retained": True,
                },
            }
        },
    ),
    "CMSEncoderCopySupportingCerts": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecKeychainItemSetAccess": (b"i@@",),
    "sec_protocol_options_set_tls_resumption_enabled": (b"vBB",),
    "SSLHandshake": (b"i@",),
    "SecKeychainAddCallback": (
        b"i^?I^v",
        "",
        {
            "arguments": {
                0: {
                    "callable": {
                        "retval": {"type": b"i"},
                        "arguments": {
                            0: {"type": b"I"},
                            1: {
                                "type": b"^{SecKeychainCallbackInfo=I^{__SecKeychainItem=}^{__SecKeychain=}i}"
                            },
                            2: {"type": b"^v"},
                        },
                    }
                }
            }
        },
    ),
    "SecureDownloadCopyURLs": (
        b"i^{OpaqueSecureDownload=}o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "CMSEncoderAddRecipients": (b"i@@",),
    "SecKeychainGetCSPHandle": (b"i^{__SecKeychain=}^q",),
    "SecTrustCopyPublicKey": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "SecKeyCreateWithData": (b"@@@o^@", "", {"retval": {"already_cfretained": True}}),
    "sec_protocol_metadata_get_negotiated_tls_protocol_version": (b"S@",),
    "SecKeychainDelete": (b"i@",),
    "sec_identity_copy_certificates_ref": (
        b"@@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "AuthorizationRightSet": (
        b"i^{AuthorizationOpaqueRef=}^t@@@@",
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}}},
    ),
    "SecACLRemove": (b"i@",),
    "CMSDecoderCopyDetachedContent": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecKeychainCreate": (
        b"in^tIn^vZ@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                0: {"c_array_delimited_by_null": True},
                2: {"c_array_length_in_arg": 1},
                5: {"already_cfretained": True},
            },
        },
    ),
    "SecEncryptTransformGetTypeID": (b"Q",),
    "SSLGetDiffieHellmanParams": (
        b"i@o^vN^L",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "SSLSetSessionConfig": (b"i@@",),
    "SecCertificateCreateWithData": (
        b"@@@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecRequirementCopyData": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "CMSDecoderCopyEncapsulatedContentType": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecRequirementCreateWithStringAndErrors": (
        b"i@Io^@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                },
                3: {"already_cfretained": True},
            },
        },
    ),
    "SSLReHandshake": (b"i@",),
    "sec_protocol_metadata_get_negotiated_ciphersuite": (b"I@",),
    "SecTransformCustomGetAttribute": (b"@^{OpaqueSecTransformImplementation=}@q",),
    "sec_protocol_options_get_enable_encrypted_client_hello": (b"B@",),
    "SSLCopyRequestedPeerName": (
        b"i@o^tN^L",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "CMSDecoderCopySignerCert": (
        b"i@Lo^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecTrustCopyExceptions": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "SecPolicyCreateSSL": (b"@Z@", "", {"retval": {"already_cfretained": True}}),
    "SecKeychainItemCreatePersistentReference": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SSLCopyCertificateAuthorities": (
        b"i@o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "SecTransformConnectTransforms": (
        b"@@@@@@o^@",
        "",
        {
            "arguments": {
                5: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            }
        },
    ),
    "SecAccessCopyACLList": (
        b"i@o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "SecHostSelectedGuest": (b"iIo^I",),
    "sec_protocol_options_get_default_min_tls_protocol_version": (b"i",),
    "SecAccessCopyMatchingACLList": (
        b"@@@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecKeychainItemCreateCopy": (
        b"i@@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"already_cfretained": True}},
        },
    ),
    "SecKeyGeneratePairAsync": (
        b"v@^{dispatch_queue_s=}@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                            3: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "SecCertificateCopyData": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "sec_protocol_options_set_tls_max_version": (b"v@i",),
    "SecKeyGenerateSymmetric": (b"@@o^@", "", {"retval": {"already_cfretained": True}}),
    "SecHostSetGuestStatus": (b"iII@I",),
    "CMSDecoderCopySignerStatus": (
        b"i@L@Zo^Io^i^i",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecTrustCopyCustomAnchorCertificates": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "CMSEncoderCopySignerTimestampWithPolicy": (
        b"i@@Lo^d",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecTrustSettingsImportExternalRepresentation": (b"iI@",),
    "SecTrustCreateWithCertificates": (
        b"i@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecHostSetHostingPort": (b"iII",),
    "sec_protocol_options_set_tls_sct_enabled": (b"vBB",),
    "SecDecryptTransformGetTypeID": (b"Q",),
    "CMSEncoderUpdateContent": (
        b"i@n^vL",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "SSLGetNegotiatedCipher": (b"i@o^i",),
    "SecTrustCopyProperties": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "SecKeyCopyKeyExchangeResult": (
        b"@@@@@o^@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecTrustEvaluateWithError": (
        b"B@o^@",
        "",
        {
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            }
        },
    ),
    "SecPolicyGetTypeID": (b"Q",),
    "SessionGetInfo": (
        b"iI^I^I",
        "",
        {"arguments": {1: {"type_modifier": "o"}, 2: {"type_modifier": "o"}}},
    ),
    "sec_protocol_metadata_access_supported_signature_algorithms": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "S"}},
                    },
                    "block": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"S"}},
                    },
                }
            }
        },
    ),
    "SecTransformFindByName": (b"@@@",),
    "SecIdentityCreateWithCertificate": (
        b"i@@o^@",
        "",
        {"arguments": {2: {"already_cfretained": True}}},
    ),
    "SecTaskCreateWithAuditToken": (
        b"@@{?=[8I]}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecCertificateCopyValues": (
        b"@@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "sec_protocol_options_get_quic_use_legacy_codepoint": (b"B@",),
    "AuthorizationCreateFromExternalForm": (
        b"in^{_AuthorizationExternalForm=[32C]}o^^{AuthorizationOpaqueRef=}",
    ),
    "CMSDecoderUpdateMessage": (
        b"i@n^vL",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "CMSEncoderCopyEncapsulatedContentType": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SSLGetConnection": (b"i@o^@",),
    "SecKeychainSetUserInteractionAllowed": (b"iZ",),
    "SecTrustSetAnchorCertificatesOnly": (b"i@Z",),
    "SSLGetPeerID": (b"i@o^vN^L", "", {"arguments": {1: {"c_array_length_in_arg": 2}}}),
    "SecTransformCreateReadTransformWithReadStream": (
        b"@@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "sec_protocol_options_set_max_tls_protocol_version": (b"v@i",),
    "SecRequirementGetTypeID": (b"Q",),
    "SSLCreateContext": (b"@@ii", "", {"retval": {"already_cfretained": True}}),
    "sec_protocol_options_set_challenge_block": (
        b"v@@?^{dispatch_queue_s}",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {
                                "callable": {
                                    "retval": {"type": "v"},
                                    "arguments": {0: {"type": "^v"}},
                                },
                                "type": "@?",
                            },
                        },
                    }
                }
            }
        },
    ),
    "CMSEncoderGetHasDetachedContent": (b"i@o^Z",),
    "SSLSetConnection": (b"i@@",),
    "SecKeychainRemoveCallback": (
        b"i^?",
        "",
        {
            "arguments": {
                0: {
                    "callable": {
                        "retval": {"type": b"i"},
                        "arguments": {
                            0: {"type": b"I"},
                            1: {
                                "type": b"^{SecKeychainCallbackInfo=I^{__SecKeychainItem=}^{__SecKeychain=}i}"
                            },
                            2: {"type": b"^v"},
                        },
                    },
                    "callable_retained": True,
                }
            }
        },
    ),
    "SecCertificateCopyPublicKey": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecPolicyCopyProperties": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "CMSEncoderSetEncapsulatedContentTypeOID": (b"i@@",),
    "SecDecodeTransformCreate": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "sec_protocol_metadata_get_negotiated_protocol": (
        b"^t@",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
    "SSLSetALPNProtocols": (b"i@@",),
    "SSLGetProtocolVersionMin": (b"i@o^i",),
    "SSLSetPeerDomainName": (
        b"i@n^tL",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "SecSignTransformCreate": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecTransformGetTypeID": (b"Q",),
    "SecKeychainGetPath": (
        b"i@N^Io^t",
        "",
        {"arguments": {2: {"c_array_length_in_arg": 1}}},
    ),
    "SecCertificateCopySerialNumberData": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecCertificateCopyCommonName": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SSLGetSupportedCiphers": (
        b"i@o^iN^L",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "sec_trust_create": (b"@@", "", {"retval": {"already_retained": True}}),
    "CMSEncoderSetSignerAlgorithm": (b"i@@",),
    "SecCertificateAddToKeychain": (b"i@@",),
    "SecKeyGetBlockSize": (b"L@",),
    "SecIdentityCopyPrivateKey": (
        b"i@o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "CMSEncoderAddSupportingCerts": (b"i@@",),
    "sec_certificate_create": (b"@@", "", {"retval": {"already_retained": True}}),
    "SSLSetMaxDatagramRecordSize": (b"i@L",),
    "CMSDecoderCopySignerTimestamp": (
        b"i@Lo^d",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SSLSetDatagramHelloCookie": (
        b"i@n^vL",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "sec_identity_copy_ref": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "SecTaskGetTypeID": (b"Q",),
    "sec_protocol_options_get_default_max_tls_protocol_version": (b"i",),
    "SSLSetIOFuncs": (
        b"i@^?^?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"i"},
                        "arguments": {
                            0: {"type": "@"},
                            1: {"type": "o^v", "c_array_length_in_arg": 2},
                            2: {"type": "N^L"},
                        },
                    },
                    "callable_retained": True,
                },
                2: {
                    "callable": {
                        "retval": {"type": b"i"},
                        "arguments": {
                            0: {"type": "@"},
                            1: {"type": "n^v", "c_array_length_in_arg": 2},
                            2: {"type": "N^L"},
                        },
                    },
                    "callable_retained": True,
                },
            }
        },
    ),
    "SecKeychainOpen": (
        b"in^to^@",
        "",
        {
            "arguments": {
                0: {"c_array_delimited_by_null": True},
                1: {"already_cfretained": True},
            }
        },
    ),
    "SecCodeGetTypeID": (b"Q",),
    "SecRequirementCreateWithData": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "sec_protocol_options_set_min_tls_protocol_version": (b"v@i",),
    "SecCodeCopySigningInformation": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SSLSetProtocolVersionMax": (b"i@i",),
    "sec_protocol_metadata_access_pre_shared_keys": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                        },
                    },
                    "block": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}, 1: {"type": b"@"}},
                    },
                }
            }
        },
    ),
    "SecKeychainGetStatus": (b"i@o^I",),
    "SSLGetClientCertificateState": (b"i@o^i",),
    "CMSDecoderCopySignerTimestampCertificates": (
        b"i@Lo^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecureDownloadFinished": (b"i^{OpaqueSecureDownload=}",),
    "CMSEncoderSetCertificateChainMode": (b"i@I",),
    "SecAccessControlCreateWithFlags": (
        b"@@@Qo^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                3: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecTrustEvaluateAsync": (
        b"i@^{dispatch_queue_s}@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "I"},
                        },
                    }
                }
            }
        },
    ),
    "SecureDownloadCopyName": (
        b"i^{OpaqueSecureDownload=}o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "SSLCopyALPNProtocols": (
        b"i@o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "SecKeychainCopySearchList": (
        b"io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {0: {"already_cfretained": True}},
        },
    ),
    "SecDigestTransformGetTypeID": (b"Q",),
    "SecTrustSetOptions": (b"i@I",),
    "SSLGetNumberEnabledCiphers": (b"i@o^L",),
    "SecIdentityGetTypeID": (sel32or64(b"I", b"Q"),),
    "SecCreateSharedWebCredentialPassword": (
        b"@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecKeychainCopyAccess": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "sec_protocol_options_set_tls_pre_shared_key_identity_hint": (b"v@@",),
    "CMSEncoderGetTypeID": (b"Q",),
    "SecTrustCopyCertificateChain": (
        b"^{__CFArray=}^{__SecTrust=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecTransformGetAttribute": (b"@@@",),
    "CMSDecoderGetNumSigners": (b"i@o^L",),
    "SecCertificateCopyPreferred": (
        b"@@@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "sec_protocol_options_set_local_identity": (b"v@@",),
    "sec_protocol_options_set_tls_min_version": (b"v@i",),
    "SecRandomCopyBytes": (
        b"i^{__SecRandom=}L^v",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"c_array_length_in_arg": 1, "type_modifier": "o"}},
        },
    ),
    "CMSDecoderFinalizeMessage": (b"i@",),
    "SecKeyWrapSymmetric": (b"@@@@o^@", "", {"retval": {"already_cfretained": True}}),
    "SecVerifyTransformCreate": (
        b"@@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecCodeCheckValidity": (b"i@I@",),
    "CMSEncoderCopyEncodedContent": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "CMSEncoderAddSigners": (b"i@@",),
    "sec_protocol_metadata_copy_peer_public_key": (
        b"@@",
        "",
        {"retval": {"already_retained": True}},
    ),
    "AuthorizationFree": (b"i^{AuthorizationOpaqueRef=}I",),
    "SecCopyErrorMessageString": (
        b"@i^v",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CMSEncoderCopySigners": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecureDownloadRelease": (b"i^{OpaqueSecureDownload=}",),
    "SecTrustSettingsCopyModificationDate": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecureDownloadUpdateWithData": (b"i^{OpaqueSecureDownload=}@",),
    "SecKeychainCopyDomainDefault": (
        b"iio^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecItemDelete": (b"i@",),
    "SecStaticCodeCheckValidity": (b"i@I@",),
    "sec_protocol_metadata_create_secret_with_context": (
        b"@@L^tL^vL",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {
                2: {"c_array_length_in_arg": 1, "type_modifier": "n"},
                4: {"c_array_length_in_arg": 3, "type_modifier": "n"},
            },
        },
    ),
    "SecCodeCopyHost": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "sec_protocol_metadata_challenge_parameters_are_equal": (b"B@@",),
    "SecTrustedApplicationGetTypeID": (b"Q",),
    "SecTransformSetDataAction": (
        b"@^{OpaqueSecTransformImplementation=}@@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"@"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "SecKeychainAddGenericPassword": (
        b"i@In^tIn^tIn^vo^@",
        "",
        {
            "arguments": {
                2: {"c_array_length_in_arg": 1},
                4: {"c_array_length_in_arg": 3},
                6: {"c_array_length_in_arg": 5},
                7: {"already_cfretained": True},
            }
        },
    ),
    "sec_protocol_options_add_tls_application_protocol": (
        b"v@^t",
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}}},
    ),
    "CMSDecoderCopySignerTimestampWithPolicy": (
        b"i@@Lo^d",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"already_cfretained": True}},
        },
    ),
    "SecCodeCreateWithXPCMessage": (
        b"i@I^^{__SecCode=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "SSLRead": (
        b"i@o^vLo^L",
        "",
        {"arguments": {1: {"c_array_length_in_arg": (2, 3)}}},
    ),
    "SecTaskCopyValueForEntitlement": (
        b"@@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "sec_protocol_metadata_get_negotiated_tls_ciphersuite": (b"I@",),
    "SSLGetDatagramWriteSize": (b"i@o^L",),
    "SecIdentitySetPreferred": (b"i@@@",),
    "SecTrustCopyAnchorCertificates": (
        b"io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {0: {"already_cfretained": True}},
        },
    ),
    "sec_protocol_options_add_tls_ciphersuite": (b"v@i",),
    "SecKeychainSetDomainDefault": (b"ii@",),
    "sec_protocol_options_get_default_max_dtls_protocol_version": (b"i",),
    "SecCertificateGetTypeID": (b"Q",),
    "SecCertificateCopyShortDescription": (
        b"@@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SSLCopyRequestedPeerNameLength": (b"i@o^L",),
    "CMSEncoderCopySignerTimestamp": (
        b"i@Lo^d",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SSLSetClientSideAuthenticate": (b"i@i",),
    "sec_protocol_metadata_get_early_data_accepted": (b"B@",),
    "SecCodeCopySelf": (
        b"iIo^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SSLGetNumberSupportedCiphers": (b"i@o^L",),
    "SecIdentityCopyPreferred": (b"@@@@", "", {"retval": {"already_cfretained": True}}),
    "SecACLUpdateAuthorizations": (b"i@@",),
    "SecAccessGetTypeID": (sel32or64(b"I", b"Q"),),
    "SecKeychainItemGetTypeID": (b"Q",),
    "SecTrustSetKeychains": (b"i@@",),
    "SSLGetProtocolVersionMax": (b"i@o^i",),
    "SecKeyCreateDecryptedData": (
        b"@@@@o^@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecKeyCopyPublicKey": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "SecGroupTransformGetTypeID": (b"Q",),
    "SecKeychainCopySettings": (
        b"i@o^{SecKeychainSettings=IZZI}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecTrustSettingsCreateExternalRepresentation": (
        b"iIo^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecCertificateCopyKey": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "SecTrustGetTrustResult": (b"i@o^I",),
    "SSLSetDiffieHellmanParams": (
        b"i@n^vL",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "SecTrustSettingsRemoveTrustSettings": (b"i@I",),
    "SecRequirementCreateWithString": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecKeychainSetDomainSearchList": (b"ii@",),
    "sec_protocol_options_set_tls_diffie_hellman_parameters": (b"v@@",),
    "sec_protocol_options_set_tls_is_fallback_attempt": (b"vBB",),
    "SecRequirementCopyString": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SSLWrite": (b"i@n^vLo^L", "", {"arguments": {1: {"c_array_length_in_arg": 2}}}),
    "sec_protocol_metadata_peers_are_equal": (b"B@@",),
    "SSLSetPeerID": (b"i@n^vL", "", {"arguments": {1: {"c_array_length_in_arg": 2}}}),
    "sec_protocol_options_get_default_min_dtls_protocol_version": (b"i",),
    "SecTransformCreate": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecCertificateCopyNormalizedSubjectSequence": (
        b"@@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecKeychainCopyDomainSearchList": (
        b"iio^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecKeyCreateFromData": (b"@@@o^@", "", {"retval": {"already_cfretained": True}}),
    "SecTaskCopyValuesForEntitlements": (
        b"@@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecStaticCodeGetTypeID": (b"Q",),
    "SecItemExport": (
        b"i@IIn^{_SecItemImportExportKeyParameters=II@@@@@@}o^@",
        "",
        {"arguments": {4: {"already_cfretained": True}}},
    ),
    "SSLSetProtocolVersionMin": (b"i@i",),
    "SecCertificateCopyLongDescription": (
        b"@@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecKeychainSetAccess": (b"i@@",),
    "sec_protocol_options_set_pre_shared_key_selection_block": (
        b"v@@?^{dispatch_queue_s}",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                            3: {
                                "callable": {
                                    "retval": {"type": "v"},
                                    "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                                },
                                "type": "@?",
                            },
                        },
                    }
                }
            }
        },
    ),
    "sec_protocol_options_add_pre_shared_key": (b"v@@@",),
    "SecKeychainSetSearchList": (b"i@",),
    "CMSEncoderCopyRecipients": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "sec_protocol_options_set_key_update_block": (
        b"v@@?^{dispatch_queue_s}",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {
                                "callable": {
                                    "retval": {"type": "v"},
                                    "arguments": {0: {"type": "^v"}},
                                },
                                "type": "@?",
                            },
                        },
                    }
                }
            }
        },
    ),
    "SecACLCopyAuthorizations": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "SecTrustEvaluateAsyncWithError": (
        b"i@^{dispatch_queue_s}@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "B"},
                            3: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "SSLGetEnabledCiphers": (
        b"i@o^iN^L",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "SecKeychainGetPreferenceDomain": (b"io^i",),
    "SecKeychainGetVersion": (b"io^I",),
    "SecKeyCreateRandomKey": (b"@@o^@", "", {"retval": {"already_cfretained": True}}),
    "sec_protocol_options_set_tls_renegotiation_enabled": (b"vBB",),
    "SSLGetPeerDomainNameLength": (b"i@o^L",),
    "sec_protocol_options_are_equal": (b"B@@",),
    "SecCertificateCopySubjectSummary": (
        b"@@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CMSDecoderCopySignerEmailAddress": (
        b"i@Lo^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecTrustSetSignedCertificateTimestamps": (b"i@@",),
    "SecTrustSetOCSPResponse": (b"i@@",),
    "SSLSetCertificateAuthorities": (b"i@@Z",),
    "SecACLCreateWithSimpleContents": (
        b"i@@@So^@",
        "",
        {"arguments": {4: {"already_cfretained": True}}},
    ),
    "SecTrustGetTypeID": (b"Q",),
    "SecTrustedApplicationCreateFromPath": (
        b"i^to^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                0: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                1: {"already_cfretained": True},
            },
        },
    ),
    "SSLSetOCSPResponse": (b"i@@",),
    "SecTrustGetVerifyTime": (b"d@",),
    "SecTransformExecuteAsync": (
        b"v@^{dispatch_queue_s=}@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                            3: {"type": "Z"},
                        },
                    }
                }
            }
        },
    ),
    "SecIdentityCopyCertificate": (
        b"i@o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "SecRequestSharedWebCredential": (
        b"v@@@?",
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                        },
                    }
                }
            }
        },
    ),
    "SecKeychainAddInternetPassword": (
        b"i@In^tIn^tIn^tIn^tSIIIn^vo^@",
        "",
        {
            "arguments": {
                2: {"c_array_length_in_arg": 1},
                4: {"c_array_length_in_arg": 3},
                6: {"c_array_length_in_arg": 5},
                8: {"c_array_length_in_arg": 7},
                13: {"c_array_length_in_arg": 12},
                14: {"already_cfretained": True},
            }
        },
    ),
    "SecKeychainSetSettings": (b"i@n^{SecKeychainSettings=IZZI}",),
    "SecIdentitySetSystemIdentity": (
        b"i@o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "CMSEncoderSetHasDetachedContent": (b"i@Z",),
    "SecEncodeTransformCreate": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecKeychainGetUserInteractionAllowed": (b"io^Z",),
    "sec_protocol_metadata_create_secret": (
        b"@@L^tL",
        "",
        {
            "retval": {"already_retained": True},
            "arguments": {2: {"c_array_length_in_arg": 1, "type_modifier": "n"}},
        },
    ),
    "SecTrustCopyPolicies": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecKeychainSetDefault": (b"i@",),
    "SecCodeCopyGuestWithAttributes": (
        b"i@@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"already_cfretained": True}},
        },
    ),
    "SecTrustSetAnchorCertificates": (b"i@@",),
    "SecKeychainGetTypeID": (b"Q",),
    "SecCertificateSetPreferred": (b"i@@@",),
    "SecCertificateCopyNormalizedIssuerSequence": (
        b"@@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "sec_protocol_options_set_enable_encrypted_client_hello": (b"v@B",),
    "sec_protocol_options_set_tls_server_name": (
        b"v@^t",
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}}},
    ),
    "SecKeyGetTypeID": (sel32or64(b"I", b"Q"),),
    "sec_protocol_options_set_quic_use_legacy_codepoint": (b"v@B",),
    "sec_protocol_set_local_identity": (b"v@@",),
    "sec_protocol_metadata_get_negotiated_protocol_version": (b"i@",),
    "SecItemCopyMatching": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecItemUpdate": (b"i@@",),
    "CMSDecoderGetTypeID": (b"Q",),
    "SecTrustedApplicationCopyData": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecKeychainItemCopyAccess": (
        b"i@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True}},
        },
    ),
    "SecKeyUnwrapSymmetric": (
        b"@n^@@@o^@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecTaskCopySigningIdentifier": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "SecureDownloadCopyTicketLocation": (
        b"i^{OpaqueSecureDownload=}o^@",
        "",
        {"arguments": {1: {"already_cfretained": True}}},
    ),
    "sec_protocol_options_set_verify_block": (
        b"v@@?^{dispatch_queue_s}",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "@"},
                            2: {"type": "@"},
                            3: {
                                "callable": {
                                    "retval": {"type": "v"},
                                    "arguments": {0: {"type": "^v"}},
                                },
                                "type": "@?",
                            },
                        },
                    }
                }
            }
        },
    ),
    "SecAddSharedWebCredential": (
        b"v@@@@?",
        "",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    }
                }
            }
        },
    ),
    "SecTranformCustomGetAttribute": (b"@^{OpaqueSecTransformImplementation=}@q",),
    "SecKeychainCopyDefault": (
        b"io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {0: {"already_cfretained": True}},
        },
    ),
    "SSLSetEnabledCiphers": (
        b"i@n^iL",
        "",
        {"arguments": {1: {"c_array_length_in_arg": 2}}},
    ),
    "sec_protocol_metadata_access_peer_certificate_chain": (
        b"B@@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": "^v"}, 1: {"type": "@"}},
                    },
                    "block": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"@"}},
                    },
                }
            }
        },
    ),
    "SecHostRemoveGuest": (b"iIII",),
    "SSLClose": (b"i@",),
    "SecKeyDeriveFromPassword": (
        b"@@@o^@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SecAccessControlGetTypeID": (b"Q",),
    "SecKeyCopyAttributes": (b"@@", "", {"retval": {"already_cfretained": True}}),
    "AuthorizationRightRemove": (
        b"i^{AuthorizationOpaqueRef=}^t",
        "",
        {"arguments": {1: {"c_array_delimited_by_null": True, "type_modifier": "n"}}},
    ),
    "SecTrustSettingsCopyTrustSettings": (
        b"i@Io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True}},
        },
    ),
    "SecEncryptTransformCreate": (
        b"@@o^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "CMSEncoderCreate": (
        b"io^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {0: {"already_cfretained": True}},
        },
    ),
    "CMSEncodeContent": (
        b"i@@@ZIn^vLo^@",
        "",
        {
            "arguments": {
                5: {"c_array_length_in_arg": 6},
                7: {"already_cfretained": True},
            }
        },
    ),
}
aliases = {
    "errSSLServerAuthCompleted": "errSSLPeerAuthCompleted",
    "SecTransformCustomGetAttribute": "SecTranformCustomGetAttribute",
    "errSessionInvalidFlags": "errAuthorizationInvalidFlags",
    "errSecDskFull": "errSecDiskFull",
    "errSecCSSigDBAccess": "errSecCSDBAccess",
    "SEC_ASN1_TELETEX_STRING": "SEC_ASN1_T61_STRING",
    "errSSLLast": "errSSLUnexpectedRecord",
    "SEC_OS_OSX": "TARGET_OS_OSX",
    "errSessionInternal": "errAuthorizationInternal",
    "SEC_DEPRECATED_ATTRIBUTE": "DEPRECATED_ATTRIBUTE",
    "errSecInvalidTupleCredendtials": "errSecInvalidTupleCredentials",
    "SEC_OS_IPHONE": "TARGET_OS_IPHONE",
    "errSecInvaldCRLAuthority": "errSecInvalidCRLAuthority",
    "kSecRequirementTypeCount": "kSecInvalidRequirementType",
    "errSSLClientAuthCompleted": "errSSLPeerAuthCompleted",
    "errSecCSSigDBDenied": "errSecCSDBDenied",
    "SEC_OS_OSX_INCLUDES": "TARGET_OS_OSX",
}
cftypes = [
    ("SecACLRef", b"^{__SecACL=}", "SecACLGetTypeID", None),
    (
        "SecAccessControlRef",
        b"^{__SecAccessControl=}",
        "SecAccessControlGetTypeID",
        None,
    ),
    ("SecAccessRef", b"^{__SecAccess=}", "SecAccessGetTypeID", None),
    ("SecCertificateRef", b"^{__SecCertificate=}", "SecCertificateGetTypeID", None),
    ("SecCodeRef", b"^{__SecCode=}", "SecCodeGetTypeID", None),
    ("SecIdentityRef", b"^{__SecIdentity=}", "SecIdentityGetTypeID", None),
    ("SecKeyRef", b"^{__SecKey=}", "SecKeyGetTypeID", None),
    ("SecKeychainItemRef", b"^{__SecKeychainItem=}", "SecKeyChainItemGetTypeID", None),
    ("SecKeychainRef", b"^{__SecKeychain=}", "SecKeyChainGetTypeID", None),
    ("SecPasswordRef", b"^{__SecPassword=}", "SecPasswordGetTypeID", None),
    ("SecPolicyRef", b"^{__SecPolicy=}", "SecPolicyGetTypeID", None),
    ("SecRequirementRef", b"^{__SecRequirement=}", "SecRequirementGetTypeID", None),
    ("SecStaticCodeRef", b"^{__SecCode=}", None, None),
    ("SecTaskRef", b"^{__SecTask=}", "SecTaskGetTypeID", None),
    ("SecTrustRef", b"^{__SecTrust=}", "SecTrustGetTypeID", None),
    (
        "SecTrustedApplicationRef",
        b"^{__SecTrustedApplication=}",
        "SecTrustedApplicationGetTypeID",
        None,
    ),
    ("CMSEncoderRef", b"^{_CMSEncoder=}", "CMSEncoderGetTypeID", None),
    ("CMSDecoderRef", b"^{_CMSDecoder=}", "CMSDecoderGetTypeID", None),
    ("SSLContextRef", b"^{SSLContext=}", "SSLContextGetTypeID", None),
]
misc.update(
    {
        "AuthorizationRef": objc.createOpaquePointerType(
            "AuthorizationRef", b"^{AuthorizationOpaqueRef=}"
        ),
        "SecureDownloadRef": objc.createOpaquePointerType(
            "SecureDownloadRef", b"^{OpaqueSecureDownload=}"
        ),
        "SecRandomRef": objc.createOpaquePointerType(
            "SecRandomRef", b"^{__SecRandom=}"
        ),
        "SecTransformImplementationRef": objc.createOpaquePointerType(
            "SecTransformImplementationRef", b"^{OpaqueSecTransformImplementation=}"
        ),
    }
)
expressions = {"kAuthorizationEmptyEnvironment": "None"}

# END OF FILE
